@@ -161,13 +161,13 @@ void ActionManagerImpl::initTrayIcon(TrayIcon* trayIcon)
 
     if (actionCollection()->action("feed_fetch_all"))
         traypop->addAction(actionCollection()->action("feed_fetch_all"));
-    if (actionCollection()->action("akregator_configure_akregator"))
-        traypop->addAction(actionCollection()->action("akregator_configure_akregator"));
+    if (actionCollection()->action("options_configure"))
+        traypop->addAction(actionCollection()->action("options_configure"));
 }
 
 void ActionManagerImpl::initPart()
 {
-    QAction *action = d->actionCollection->addAction("file_import");
+    KAction *action = d->actionCollection->addAction("file_import");
     action->setText(i18n("&Import Feeds..."));
     action->setIcon(KIcon("document-import"));
     connect(action, SIGNAL(triggered(bool)), d->part, SLOT(fileImport()));
@@ -176,11 +176,15 @@ void ActionManagerImpl::initPart()
     action->setIcon(KIcon("document-export"));
     connect(action, SIGNAL(triggered(bool)), d->part, SLOT(fileExport()));
 
-    KStandardAction::configureNotifications(d->part, SLOT(showKNotifyOptions()), d->actionCollection); // options_configure_notifications
-    action = d->actionCollection->addAction("akregator_configure_akregator");
+    KAction *configure = d->actionCollection->addAction("options_configure");
+    configure->setText(i18n("&Configure Akregator..."));
+    configure->setIcon(KIcon("configure"));
+    connect(configure, SIGNAL(triggered()), d->part, SLOT(showOptions()));
+
+    /*action = d->actionCollection->addAction("akregator_configure_akregator");
     action->setIcon(KIcon("configure"));
     action->setText(i18n("Configure &Akregator..."));
-    connect(action, SIGNAL(triggered(bool)), d->part, SLOT(showOptions()));
+    connect(action, SIGNAL(triggered(bool)), d->part, SLOT(showOptions()));*/
 }
 
 void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
@@ -193,7 +197,7 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
     KActionCollection* coll = actionCollection();
 
     // Feed/Feed Group popup menu
-    QAction* action = coll->addAction("feed_homepage");
+    KAction* action = coll->addAction("feed_homepage");
     action->setText(i18n("&Open Homepage"));
     connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenHomepage()));
     action->setShortcuts(KShortcut( "Ctrl+H" ));
@@ -226,28 +230,32 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
     vm->setText(i18n("&View Mode"));
 
     QActionGroup* agViewMode = new QActionGroup(this);
+    agViewMode->setExclusive(true);
     KToggleAction *ra = coll->add<KToggleAction>("normal_view");
     ra->setIcon(KIcon("view-split-top-bottom"));
     ra->setText(i18n("&Normal View"));
-    connect(ra, SIGNAL(triggered(bool) ), d->mainWidget, SLOT(slotNormalView()));
+    connect(ra, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotNormalView()));
     ra->setShortcuts(KShortcut( "Ctrl+Shift+1" ));
     ra->setActionGroup(agViewMode);
+    ra->setChecked(mainWidget->viewMode() == MainWidget::NormalView);
     vm->addAction(ra);
 
     ra = coll->add<KToggleAction>("widescreen_view");
     ra->setIcon(KIcon("view-split-left-right"));
     ra->setText(i18n("&Widescreen View"));
-    connect(ra, SIGNAL(triggered(bool) ), d->mainWidget, SLOT(slotWidescreenView()));
+    connect(ra, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotWidescreenView()));
     ra->setShortcuts(KShortcut( "Ctrl+Shift+2" ));
     ra->setActionGroup(agViewMode);
+    ra->setChecked(mainWidget->viewMode() == MainWidget::WidescreenView);
     vm->addAction(ra);
 
     ra = coll->add<KToggleAction>("combined_view");
     ra->setIcon(KIcon("view-list-text"));
     ra->setText(i18n("C&ombined View"));
-    connect(ra, SIGNAL(triggered(bool) ), d->mainWidget, SLOT(slotCombinedView()));
+    connect(ra, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotCombinedView()));
     ra->setShortcuts(KShortcut( "Ctrl+Shift+3" ));
     ra->setActionGroup(agViewMode);
+    ra->setChecked(mainWidget->viewMode() == MainWidget::CombinedView);
     vm->addAction(ra);
 
     // toolbar / feed menu
@@ -263,7 +271,7 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
     connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotFetchAllFeeds()));
     action->setShortcuts(KShortcut( "Ctrl+L" ));
 
-    QAction *stopAction = coll->addAction("feed_stop");
+    KAction *stopAction = coll->addAction("feed_stop");
     stopAction->setIcon(KIcon("process-stop"));
     stopAction->setText(i18n("&Abort Fetches"));
     connect(stopAction, SIGNAL(triggered(bool)), Kernel::self()->fetchQueue(), SLOT(slotAbort()));
@@ -291,13 +299,13 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
     action = coll->addAction("article_open" );
     action->setIcon(KIcon("tab-new"));
     action->setText(i18n("Open in Tab"));
-    connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenCurrentArticle()));
+    connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenSelectedArticles()));
     action->setShortcuts(KShortcut( "Shift+Return" ));
 
     action = coll->addAction("article_open_external" );
     action->setIcon(KIcon("window-new"));
     action->setText(i18n("Open in External Browser"));
-    connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenCurrentArticleInBrowser()));
+    connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenSelectedArticlesInBrowser()));
     action->setShortcuts(KShortcut( "Ctrl+Shift+Return" ));
 
     action = coll->addAction("article_copy_link_address" );
@@ -322,6 +330,7 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
 
     KActionMenu* statusMenu = coll->add<KActionMenu>("article_set_status");
     statusMenu->setText(i18n("&Mark As"));
+    statusMenu->setEnabled( false );
 
     //d->speakSelectedArticlesAction = new KAction(KIcon("media-playback-start"), i18n("&Speak Selected Articles"), actionCollection(), "akr_texttospeech");
     //connect(d->speakSelectedArticlesAction, SIGNAL(triggered(bool) ), d->mainWidget, SLOT(slotTextToSpeechRequest()));
@@ -343,7 +352,7 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
     statusMenu->addAction(action);
 
     action = coll->addAction("article_set_status_new");
-    action->setText(i18n("&New"));
+    action->setText(i18nc("as in: mark as new", "&New"));
     action->setIcon(KIcon("mail-mark-unread-new"));
     action->setShortcuts(KShortcut( "Ctrl+N" ));
     action->setToolTip(i18n("Mark selected article as new"));
@@ -352,7 +361,7 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
 
 
     action = coll->addAction("article_set_status_unread");
-    action->setText(i18n("&Unread"));
+    action->setText(i18nc("as in: mark as unread", "&Unread"));
     action->setIcon(KIcon("mail-mark-unread"));
     action->setToolTip(i18n("Mark selected article as unread"));
     action->setShortcuts(KShortcut( "Ctrl+U" ));
@@ -395,6 +404,8 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
     action->setIcon(KIcon("mail-message-new"));
     action->setText(i18n("Send &File..."));
     connect(action, SIGNAL(triggered(bool)), mainWidget, SLOT(slotSendFile()));
+
+    setArticleActionsEnabled( false );
 }
 
 void ActionManagerImpl::initArticleViewer(ArticleViewer* articleViewer)
@@ -412,7 +423,7 @@ void ActionManagerImpl::initArticleListView(ArticleListView* articleList)
     else
         d->articleList = articleList;
 
-    QAction *action = actionCollection()->addAction("go_previous_article");
+    KAction *action = actionCollection()->addAction("go_previous_article");
     action->setText(i18n("&Previous Article"));
     connect(action, SIGNAL(triggered(bool)), articleList, SLOT(slotPreviousArticle()));
     action->setShortcuts(KShortcut( "Left" ));
@@ -431,7 +442,7 @@ void ActionManagerImpl::initSubscriptionListView(SubscriptionListView* subscript
 
     KActionCollection *coll = actionCollection();
 
-    QAction *action = coll->addAction("go_prev_feed");
+    KAction *action = coll->addAction("go_prev_feed");
     action->setText(i18n("&Previous Feed"));
     connect(action, SIGNAL(triggered(bool)), subscriptionListView, SLOT(slotPrevFeed()));
     action->setShortcuts(KShortcut( "P" ));
@@ -491,7 +502,7 @@ void ActionManagerImpl::initTabWidget(TabWidget* tabWidget)
 
     KActionCollection *coll = actionCollection();
 
-    QAction *action = coll->addAction("select_next_tab");
+    KAction *action = coll->addAction("select_next_tab");
     action->setText(i18n("Select Next Tab"));
     connect(action, SIGNAL(triggered(bool)), d->tabWidget, SLOT(slotNextTab()));
     action->setShortcuts(KShortcut( "Ctrl+Period" ));
@@ -539,9 +550,9 @@ void ActionManagerImpl::initFrameManager(FrameManager* frameManager)
 
     connect(back->menu(), SIGNAL(aboutToShow()), frameManager, SLOT(slotBrowserBackAboutToShow()));
 
-    QAction *action = d->actionCollection->addAction("browser_reload");
+    KAction *action = d->actionCollection->addAction("browser_reload");
     action->setIcon(KIcon("view-refresh"));
-    action->setText(i18n("Reload"));
+    action->setText(i18nc("Reload current page", "Reload"));
     connect(action, SIGNAL(triggered(bool) ), frameManager, SLOT(slotBrowserReload()));
 
     action = d->actionCollection->addAction("browser_stop");
@@ -566,6 +577,19 @@ QAction* ActionManagerImpl::action(const char* name)
     return d->actionCollection != 0 ? d->actionCollection->action(name) : 0;
 }
 
+void ActionManagerImpl::setArticleActionsEnabled( bool enabled ) {
+#undef setActionEnabled
+#define setActionEnabled(name) { QAction* const a = action( name ); if ( a ) a->setEnabled( enabled ); }
+    setActionEnabled("article_open")
+    setActionEnabled("article_open_external")
+    setActionEnabled("article_set_status_important")
+    setActionEnabled("article_set_status")
+    setActionEnabled("article_delete")
+    setActionEnabled("file_sendlink")
+    setActionEnabled("file_sendfile")
+#undef setActionEnabled
+}
+
 } // namespace Akregator
 
 #include "actionmanagerimpl.moc"
