@@ -14,44 +14,52 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
     without including the source code for Qt in the source distribution.
 */
 
+#include "cardview.h"
 
 #include <limits.h>
 
-#include <qcursor.h>
-#include <qdatetime.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qstyle.h>
-#include <qtimer.h>
-#include <qtooltip.h>
+#include <Qt3Support/Q3PtrList>
+#include <QtCore/QDateTime>
+#include <QtCore/QEvent>
+#include <QtCore/QTimer>
+#include <QtGui/QCursor>
+#include <QtGui/QFocusEvent>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QLabel>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPainter>
+#include <QtGui/QResizeEvent>
+#include <QtGui/QStyle>
+#include <QtGui/QStyleOption>
+#include <QtGui/QToolTip>
+#include <QtGui/QWheelEvent>
 
 #include <kdebug.h>
 #include <kglobalsettings.h>
 
-#include "cardview.h"
-
 #define MIN_ITEM_WIDTH 80
 
 class CardViewTip : public QLabel
 {
   public:
     CardViewTip( QWidget *parent = 0, const char *name = 0 )
-      : QLabel( parent, name )
+      : QLabel( parent )
     {
+      setObjectName( name );
       setPalette( QToolTip::palette() );
       setFrameStyle( Panel | Plain );
       setMidLineWidth( 0 );
       setIndent( 1 );
     }
 
-    ~CardViewTip() {};
+    ~CardViewTip() {}
 
   protected:
     void leaveEvent( QEvent* )
@@ -64,11 +72,11 @@ class CardViewTip : public QLabel
 // Warning: make sure you use findRef() instead of find() to find an
 //          item! Only the pointer value is unique in the list.
 //
-class CardViewItemList : public QPtrList<CardViewItem>
+class CardViewItemList : public Q3PtrList<CardViewItem>
 {
   protected:
-    virtual int compareItems( QPtrCollection::Item item1,
-                              QPtrCollection::Item item2 ) const
+    virtual int compareItems( Q3PtrCollection::Item item1,
+                              Q3PtrCollection::Item item2 )
     {
       CardViewItem *cItem1 = (CardViewItem*)item1;
       CardViewItem *cItem2 = (CardViewItem*)item2;
@@ -101,10 +109,10 @@ class CardViewSeparator
 
     ~CardViewSeparator() {}
 
-    void paintSeparator( QPainter *p, QColorGroup &cg )
+    void paintSeparator( QPainter *p, const QPalette &pal )
     {
       p->fillRect( 0, 0, mRect.width(), mRect.height(),
-                   cg.brush(QColorGroup::Button) );
+                   pal.brush(QPalette::Button) );
     }
 
     void repaintSeparator()
@@ -136,11 +144,11 @@ class CardViewPrivate
        mCurrentItem( 0L ),
        mLastClickPos( QPoint(0, 0) ),
        mRubberBandAnchor( 0 ),
-       mCompText( QString::null )
-    {};
+       mCompText( QString() )
+    {}
 
     CardViewItemList mItemList;
-    QPtrList<CardViewSeparator> mSeparatorList;
+    Q3PtrList<CardViewSeparator> mSeparatorList;
     QFontMetrics *mFm;
     QFontMetrics *mBFm;
     QFont mHeaderFont;
@@ -167,11 +175,11 @@ class CardViewPrivate
     // data used for resizing.
     // as they are beeded by each mouse move while resizing, we store them here,
     // saving 8 calculations in each mouse move.
-    int colspace;               // amount of space between items pr column
-    uint first;                 // the first col to anchor at for painting rubber bands
-    int firstX;                 // X position of first in pixel
-    int pressed;                // the colummn that was pressed on at resizing start
-    int span;                   // pressed - first
+    int mColspace;               // amount of space between items pr column
+    uint mFirst;                 // the first col to anchor at for painting rubber bands
+    int mFirstX;                 // X position of first in pixel
+    int mPressed;                // the colummn that was pressed on at resizing start
+    int mSpan;                   // pressed - first
     // key completion
     QString mCompText;          // current completion string
     QDateTime mCompUpdated;     // ...was updated at this time
@@ -183,7 +191,7 @@ class CardViewItemPrivate
     CardViewItemPrivate() {}
 
     QString mCaption;
-    QPtrList< CardViewItem::Field > mFieldList;
+    Q3PtrList< CardViewItem::Field > mFieldList;
     bool mSelected;
     int x;                      // horizontal position, set by the view
     int y;                      // vertical position, set by the view
@@ -222,7 +230,7 @@ void CardViewItem::initialize()
     mView->insertItem( this );
 }
 
-void CardViewItem::paintCard( QPainter *p, QColorGroup &cg )
+void CardViewItem::paintCard( QPainter *p, const QPalette &pal )
 {
   if ( !mView )
     return;
@@ -234,11 +242,11 @@ void CardViewItem::paintCard( QPainter *p, QColorGroup &cg )
   bool drawLabels = mView->d->mDrawFieldLabels;
   bool drawBorder = mView->d->mDrawCardBorder;
   int mg = mView->itemMargin();
-  int w = mView->itemWidth() - (mg * 2);
-  int h = height() - (mg * 2);
+  int w = mView->itemWidth() - ( mg * 2 );
+  int h = height() - ( mg * 2 );
   const int colonWidth( fm.width( ":" ) );
   int labelXPos = 2 + mg;
-  int labelWidth = QMIN( w / 2 - 4 - mg, d->maxLabelWidth + colonWidth + 4 );
+  int labelWidth = qMin( w / 2 - 4 - mg, d->maxLabelWidth + colonWidth + 4 );
   int valueXPos = labelWidth + 4 + mg;
   int valueWidth = w - labelWidth - 4 - mg;
 
@@ -252,9 +260,9 @@ void CardViewItem::paintCard( QPainter *p, QColorGroup &cg )
 
   // Draw a simple box
   if ( isSelected() )
-    pen = QPen( cg.highlight(), 1 );
+    pen = QPen( pal.color( QPalette::Highlight ), 1 );
   else
-    pen = QPen( cg.button(), 1 );
+    pen = QPen( pal.color( QPalette::Button), 1 );
   p->setPen( pen );
 
   // Draw the border - this is only draw if the user asks for it.
@@ -263,9 +271,9 @@ void CardViewItem::paintCard( QPainter *p, QColorGroup &cg )
 
   // set the proper pen color for the caption box
   if ( isSelected() )
-    brush = cg.brush( QColorGroup::Highlight );
+    brush = pal.brush( QPalette::Highlight );
   else
-    brush = cg.brush( QColorGroup::Button );
+    brush = pal.brush( QPalette::Button );
 
   p->fillRect( mg, mg, w, 4 + bFm.height(), brush );
 
@@ -274,18 +282,18 @@ void CardViewItem::paintCard( QPainter *p, QColorGroup &cg )
   QFont bFont = mView->headerFont();
   p->setFont( bFont );
   if ( isSelected() )
-    p->setPen( cg.highlightedText() );
+    p->setPen( pal.color( QPalette::HighlightedText) );
   else
-    p->setPen( cg.buttonText() );
+    p->setPen( pal.color( QPalette::ButtonText) );
 
   p->drawText( 2 + mg, 2 + mg + bFm.ascent(), trimString( d->mCaption, w - 4, bFm ) );
   p->restore();
 
   // Go through the fields and draw them
-  QPtrListIterator<CardViewItem::Field> iter( d->mFieldList );
+  Q3PtrListIterator<CardViewItem::Field> iter( d->mFieldList );
   QString label, value;
   int yPos = mg + 4 + bFm.height() + fm.height();
-  p->setPen( cg.text() );
+  p->setPen( pal.text().color() );
 
   int fh = fm.height();
   int cln( 0 );
@@ -298,10 +306,10 @@ void CardViewItem::paintCard( QPainter *p, QColorGroup &cg )
 
     if ( drawLabels ) {
       label = trimString( (*iter)->first, labelWidth, fm );
-      p->drawText( labelXPos, yPos, label + ":" );
+      p->drawText( labelXPos, yPos, label + ':' );
     }
 
-    for ( cln = 0; cln <= maxLines; cln++ ) {
+    for ( cln = 0; cln <= maxLines; ++cln ) {
       tmp = value.section( '\n', cln, cln );
       if ( !tmp.isEmpty() )
         p->drawText( valueXPos, yPos + cln * fh, trimString( tmp, valueWidth, fm ) );
@@ -316,10 +324,14 @@ void CardViewItem::paintCard( QPainter *p, QColorGroup &cg )
 
   // if we are the current item and the view has focus, draw focus rect
   if ( mView->currentItem() == this && mView->hasFocus() ) {
-    mView->style().drawPrimitive( QStyle::PE_FocusRect, p,
+
+    QStyleOption opt;
+    /* FIXME port me properly
         QRect( 0, 0, mView->itemWidth(), h + (2 * mg) ), cg,
-        QStyle::Style_FocusAtBorder,
+        QStyle::State_FocusAtBorder,
         QStyleOption( isSelected() ? cg.highlight() : cg.base() ) );
+    */
+    mView->style()->drawPrimitive( QStyle::PE_FrameFocusRect, &opt, p, 0 );
   }
 }
 
@@ -351,11 +363,11 @@ int CardViewItem::height( bool allowCache ) const
   int fieldHeight = 0;
   int lines;
   int maxLines( mView->maxFieldLines() );
-  QPtrListIterator<CardViewItem::Field> iter( d->mFieldList );
+  Q3PtrListIterator<CardViewItem::Field> iter( d->mFieldList );
   for ( iter.toFirst(); iter.current(); ++iter ) {
     if ( !sef && (*iter)->second.isEmpty() )
       continue;
-    lines = QMIN( (*iter)->second.contains( '\n' ) + 1, maxLines );
+    lines = qMin( (*iter)->second.count( '\n' ) + 1, maxLines );
     fieldHeight += ( lines * fh ) + 2;
   }
 
@@ -383,7 +395,7 @@ void CardViewItem::insertField( const QString &label, const QString &value )
 
   if ( mView ) {
     mView->setLayoutDirty( true );
-    d->maxLabelWidth = QMAX( mView->d->mFm->width( label ), d->maxLabelWidth );
+    d->maxLabelWidth = qMax( mView->d->mFm->width( label ), d->maxLabelWidth );
   }
 }
 
@@ -391,7 +403,7 @@ void CardViewItem::removeField( const QString &label )
 {
   CardViewItem::Field *f;
 
-  QPtrListIterator<CardViewItem::Field> iter( d->mFieldList );
+  Q3PtrListIterator<CardViewItem::Field> iter( d->mFieldList );
   for ( iter.toFirst(); iter.current(); ++iter ) {
     f = *iter;
     if ( f->first == label )
@@ -462,7 +474,7 @@ void CardViewItem::setCaption( const QString &caption )
 
 QString CardViewItem::fieldValue( const QString &label ) const
 {
-  QPtrListIterator<CardViewItem::Field> iter( d->mFieldList );
+  Q3PtrListIterator<CardViewItem::Field> iter( d->mFieldList );
   for ( iter.toFirst(); iter.current(); ++iter )
     if ( (*iter)->first == label )
         return (*iter)->second;
@@ -507,7 +519,7 @@ void CardViewItem::showFullString( const QPoint &itempos, CardViewTip *tip )
     Field *_f;
     for ( _f = d->mFieldList.first(); _f != f; _f = d->mFieldList.next() )
       if ( se || ! _f->second.isEmpty() )
-        y += ( QMIN( _f->second.contains( '\n' ) + 1, maxLines ) * fh ) + 2;
+        y += ( qMin( _f->second.count( '\n' ) + 1, maxLines ) * fh ) + 2;
 
     if ( isLabel && itempos.y() > y + fh )
       return;
@@ -515,13 +527,13 @@ void CardViewItem::showFullString( const QPoint &itempos, CardViewTip *tip )
     s = isLabel ? f->first : f->second;
 
     int colonWidth = mView->d->mFm->width(":");
-    lw = drawLabels ? QMIN( w / 2 - 4 - mrg, d->maxLabelWidth + colonWidth + 4 ) : 0;
-    int mw = isLabel ? lw - colonWidth : w - lw - (mrg * 2);
+    lw = drawLabels ? qMin( w / 2 - 4 - mrg, d->maxLabelWidth + colonWidth + 4 ) : 0;
+    int mw = isLabel ? lw - colonWidth : w - lw - ( mrg * 2 );
     if ( isLabel ) {
       trimmed = mView->d->mFm->width( s ) > mw - colonWidth;
     } else {
       QRect r( mView->d->mFm->boundingRect( 0, 0, INT_MAX, INT_MAX, Qt::AlignTop|Qt::AlignLeft, s ) );
-      trimmed = r.width() > mw || r.height() / fh >  QMIN( s.contains( '\n' ) + 1, maxLines );
+      trimmed = r.width() > mw || r.height() / fh >  qMin( s.count( '\n' ) + 1, maxLines );
     }
   }
 
@@ -539,7 +551,7 @@ void CardViewItem::showFullString( const QPoint &itempos, CardViewTip *tip )
     if ( pnt.x() + tip->width() > mView->visibleWidth() )
       pnt.setX( mView->visibleWidth() - tip->width() );
     if ( pnt.y() + tip->height() > mView->visibleHeight() )
-      pnt.setY( QMAX( 0, mView->visibleHeight() - tip->height() ) );
+      pnt.setY( qMax( 0, mView->visibleHeight() - tip->height() ) );
     // show
     tip->move( pnt );
     tip->show();
@@ -560,7 +572,7 @@ CardViewItem::Field *CardViewItem::fieldAt( const QPoint & itempos ) const
   Field *f;
   for ( f = d->mFieldList.first(); f; f = d->mFieldList.next() ) {
     if ( showEmpty || !f->second.isEmpty() )
-      ypos += (QMIN( f->second.contains( '\n' )+1, maxLines ) * fh) + 2;
+      ypos += (qMin( f->second.count( '\n' )+1, maxLines ) * fh) + 2;
     if ( iy <= ypos )
       break;
   }
@@ -570,7 +582,7 @@ CardViewItem::Field *CardViewItem::fieldAt( const QPoint & itempos ) const
 
 
 CardView::CardView( QWidget *parent, const char *name )
-  : QScrollView( parent, name ),
+  : Q3ScrollView( parent, name ),
     d( new CardViewPrivate() )
 {
   d->mItemList.setAutoDelete( true );
@@ -583,16 +595,17 @@ CardView::CardView( QWidget *parent, const char *name )
   d->mBFm = new QFontMetrics( f );
   d->mTip = new CardViewTip( viewport() );
   d->mTip->hide();
-  d->mTimer = new QTimer( this, "mouseTimer" );
+  d->mTimer = new QTimer( this );
+  d->mTimer->setObjectName( "mouseTimer" );
 
   viewport()->setMouseTracking( true );
   viewport()->setFocusProxy( this );
-  viewport()->setFocusPolicy( WheelFocus );
-  viewport()->setBackgroundMode( PaletteBase );
+  viewport()->setFocusPolicy( Qt::WheelFocus );
+  viewport()->setBackgroundRole( QPalette::Base );
 
   connect( d->mTimer, SIGNAL( timeout() ), this, SLOT( tryShowFullText() ) );
 
-  setBackgroundMode( PaletteBackground, PaletteBase );
+  setBackgroundRole( QPalette::Background );
 
   // no reason for a vertical scrollbar
   setVScrollBarMode( AlwaysOff );
@@ -641,7 +654,7 @@ void CardView::setCurrentItem( CardViewItem *item )
   if ( !item )
     return;
   else if ( item->cardView() != this ) {
-    kdDebug(5720)<<"CardView::setCurrentItem: Item ("<<item<<") not owned! Backing out.."<<endl;
+    kDebug(5720)<<"CardView::setCurrentItem: Item ("<<item<<") not owned! Backing out..";
     return;
   } else if ( item == currentItem() ) {
     return;
@@ -667,7 +680,7 @@ void CardView::setCurrentItem( CardViewItem *item )
 CardViewItem *CardView::itemAt( const QPoint &viewPos ) const
 {
   CardViewItem *item = 0;
-  QPtrListIterator<CardViewItem> iter( d->mItemList );
+  Q3PtrListIterator<CardViewItem> iter( d->mItemList );
   bool found = false;
   for ( iter.toFirst(); iter.current() && !found; ++iter ) {
     item = *iter;
@@ -711,7 +724,7 @@ CardView::SelectionMode CardView::selectionMode() const
 
 void CardView::selectAll( bool state )
 {
-  QPtrListIterator<CardViewItem> iter( d->mItemList );
+  Q3PtrListIterator<CardViewItem> iter( d->mItemList );
   if ( !state ) {
     for ( iter.toFirst(); iter.current(); ++iter ) {
       if ( (*iter)->isSelected() ) {
@@ -785,7 +798,7 @@ bool CardView::isSelected( CardViewItem *item ) const
 CardViewItem *CardView::selectedItem() const
 {
   // find the first selected item
-  QPtrListIterator<CardViewItem> iter( d->mItemList );
+  Q3PtrListIterator<CardViewItem> iter( d->mItemList );
   for ( iter.toFirst(); iter.current(); ++iter ) {
     if ( (*iter)->isSelected() )
       return *iter;
@@ -805,23 +818,23 @@ int CardView::childCount() const
 }
 
 CardViewItem *CardView::findItem( const QString &text, const QString &label,
-                                  Qt::StringComparisonMode compare ) const
+                                  Q3ListBox::StringComparisonMode compare ) const
 {
   // If the text is empty, we will return null, since empty text will
   // match anything!
   if ( text.isEmpty() )
     return 0;
 
-  QPtrListIterator<CardViewItem> iter( d->mItemList );
-  if ( compare & Qt::BeginsWith ) {
+  Q3PtrListIterator<CardViewItem> iter( d->mItemList );
+  if ( compare & Q3ListBox::BeginsWith ) {
     QString value;
     for ( iter.toFirst(); iter.current(); ++iter ) {
-      value = (*iter)->fieldValue( label ).upper();
-      if ( value.startsWith( text.upper() ) )
+      value = (*iter)->fieldValue( label ).toUpper();
+      if ( value.startsWith( text.toUpper() ) )
         return *iter;
     }
   } else {
-    kdDebug(5720) << "CardView::findItem: search method not implemented" << endl;
+    kDebug(5720) <<"CardView::findItem: search method not implemented";
   }
 
   return 0;
@@ -837,13 +850,13 @@ uint CardView::columnWidth() const
 void CardView::drawContents( QPainter *p, int clipx, int clipy,
                              int clipw, int cliph )
 {
-  QScrollView::drawContents( p, clipx, clipy, clipw, cliph );
+  Q3ScrollView::drawContents( p, clipx, clipy, clipw, cliph );
 
  if ( d->mLayoutDirty )
    calcLayout();
 
   // allow setting costum colors in the viewport pale
-  QColorGroup cg = viewport()->palette().active();
+  QPalette pal = viewport()->palette();
 
   QRect clipRect( clipx, clipy, clipw, cliph );
   QRect cardRect;
@@ -851,11 +864,8 @@ void CardView::drawContents( QPainter *p, int clipx, int clipy,
   CardViewItem *item;
   CardViewSeparator *sep;
 
-  // make sure the viewport is a pure background
-  viewport()->erase( clipRect );
-
   // Now tell the cards to draw, if they are in the clip region
-  QPtrListIterator<CardViewItem> iter( d->mItemList );
+  Q3PtrListIterator<CardViewItem> iter( d->mItemList );
   for ( iter.toFirst(); iter.current(); ++iter) {
     item = *iter;
     cardRect.setRect( item->d->x, item->d->y, d->mItemWidth, item->height() );
@@ -864,13 +874,13 @@ void CardView::drawContents( QPainter *p, int clipx, int clipy,
       // Tell the card to paint
       p->save();
       p->translate( cardRect.x(), cardRect.y() );
-      item->paintCard( p, cg );
+      item->paintCard( p, pal );
       p->restore();
     }
   }
 
   // Followed by the separators if they are in the clip region
-  QPtrListIterator<CardViewSeparator> sepIter( d->mSeparatorList );
+  Q3PtrListIterator<CardViewSeparator> sepIter( d->mSeparatorList );
   for ( sepIter.toFirst(); sepIter.current(); ++sepIter ) {
     sep = *sepIter;
     sepRect = sep->mRect;
@@ -878,7 +888,7 @@ void CardView::drawContents( QPainter *p, int clipx, int clipy,
     if ( clipRect.intersects( sepRect ) || clipRect.contains( sepRect ) ) {
       p->save();
       p->translate( sepRect.x(), sepRect.y() );
-      sep->paintSeparator( p, cg );
+      sep->paintSeparator( p, pal );
       p->restore();
     }
   }
@@ -886,7 +896,7 @@ void CardView::drawContents( QPainter *p, int clipx, int clipy,
 
 void CardView::resizeEvent( QResizeEvent *event )
 {
-  QScrollView::resizeEvent( event );
+  Q3ScrollView::resizeEvent( event );
 
   setLayoutDirty( true );
 }
@@ -904,7 +914,7 @@ void CardView::calcLayout()
   // delete the old separators
   d->mSeparatorList.clear();
 
-  QPtrListIterator<CardViewItem> iter( d->mItemList );
+  Q3PtrListIterator<CardViewItem> iter( d->mItemList );
   CardViewItem *item = 0;
   CardViewSeparator *sep = 0;
   xPos += cardSpacing;
@@ -915,7 +925,7 @@ void CardView::calcLayout()
     yPos += cardSpacing;
 
     if ( yPos + item->height() + cardSpacing >= height() - horizontalScrollBar()->height() ) {
-      maxHeight = QMAX( maxHeight, yPos );
+      maxHeight = qMax( maxHeight, yPos );
 
       // Drawing in this column would be greater than the height
       // of the scroll view, so move to next column
@@ -936,7 +946,7 @@ void CardView::calcLayout()
     item->d->y = yPos;
 
     yPos += item->height();
-    maxWidth = QMAX( maxWidth, d->mItemWidth );
+    maxWidth = qMax( maxWidth, d->mItemWidth );
   }
 
   xPos += maxWidth;
@@ -944,7 +954,7 @@ void CardView::calcLayout()
 
   // Update the height of all the separators now that we know the
   // max height of a column
-  QPtrListIterator<CardViewSeparator> sepIter( d->mSeparatorList );
+  Q3PtrListIterator<CardViewSeparator> sepIter( d->mSeparatorList );
   for ( sepIter.toFirst(); sepIter.current(); ++sepIter )
     (*sepIter)->mRect.setHeight( maxHeight - 2 * cardSpacing - 2 * d->mItemMargin );
 
@@ -987,25 +997,25 @@ void CardView::setItemSpacing( uint spacing )
 
 void CardView::contentsMousePressEvent( QMouseEvent *e )
 {
-  QScrollView::contentsMousePressEvent( e );
+  Q3ScrollView::contentsMousePressEvent( e );
 
-  QPoint pos = e->pos();
-  d->mLastClickPos = pos;
+  QPoint pos = contentsToViewport( e->pos() );
+  d->mLastClickPos = e->pos();
 
-  CardViewItem *item = itemAt( pos );
+  CardViewItem *item = itemAt( e->pos() );
 
   if ( item == 0 ) {
     d->mLastClickOnItem = false;
     if ( d->mOnSeparator) {
       d->mResizeAnchor = e->x() + contentsX();
-      d->colspace = (2 * d->mItemSpacing);
-      int ccw = d->mItemWidth + d->colspace + d->mSepWidth;
-      d->first = (contentsX() + d->mSepWidth) / ccw;
-      d->pressed = (d->mResizeAnchor + d->mSepWidth) / ccw;
-      d->span = d->pressed - d->first;
-      d->firstX = d->first * ccw;
-      if ( d->firstX )
-        d->firstX -= d->mSepWidth;
+      d->mColspace = (2 * d->mItemSpacing);
+      int ccw = d->mItemWidth + d->mColspace + d->mSepWidth;
+      d->mFirst = (contentsX() + d->mSepWidth) / ccw;
+      d->mPressed = (d->mResizeAnchor + d->mSepWidth) / ccw;
+      d->mSpan = d->mPressed - d->mFirst;
+      d->mFirstX = d->mFirst * ccw;
+      if ( d->mFirstX )
+        d->mFirstX -= d->mSepWidth;
     } else {
       selectAll( false );
     }
@@ -1023,16 +1033,10 @@ void CardView::contentsMousePressEvent( QMouseEvent *e )
 
   // The RMB click
   if ( e->button() & Qt::RightButton ) {
-    // clear previous selection
-    bool blocked = signalsBlocked();
-    blockSignals( true );
-    selectAll( false );
-    blockSignals( blocked );
-
     // select current item
     item->setSelected( true );
 
-    emit contextMenuRequested( item, mapToGlobal( e->pos() ) );
+    emit contextMenuRequested( item, mapToGlobal( pos ) );
     return;
   }
 
@@ -1056,13 +1060,13 @@ void CardView::contentsMousePressEvent( QMouseEvent *e )
     item->repaintCard();
     emit selectionChanged();
   } else if ( d->mSelectionMode == CardView::Extended ) {
-    if ( (e->button() & Qt::LeftButton) && (e->state() & Qt::ShiftButton) ) {
+    if ( (e->button() & Qt::LeftButton) && (e->modifiers() & Qt::ShiftModifier) ) {
       if ( item == other )
         return;
 
       bool s = !item->isSelected();
 
-      if ( s && !(e->state() & ControlButton) ) {
+      if ( s && !(e->modifiers() & Qt::ControlModifier) ) {
         bool b = signalsBlocked();
         blockSignals( true );
         selectAll( false );
@@ -1076,14 +1080,14 @@ void CardView::contentsMousePressEvent( QMouseEvent *e )
       to = a > b ? a : b;
 
       CardViewItem *aItem;
-      for ( ; from <= to; from++ ) {
+      for ( ; from <= to; ++from ) {
         aItem = d->mItemList.at( from );
         aItem->setSelected( s );
         repaintItem( aItem );
       }
 
       emit selectionChanged();
-    } else if ( (e->button() & Qt::LeftButton) && (e->state() & Qt::ControlButton) ) {
+    } else if ( (e->button() & Qt::LeftButton) && (e->modifiers() & Qt::ControlModifier) ) {
       item->setSelected( !item->isSelected() );
       item->repaintCard();
       emit selectionChanged();
@@ -1102,16 +1106,16 @@ void CardView::contentsMousePressEvent( QMouseEvent *e )
 
 void CardView::contentsMouseReleaseEvent( QMouseEvent *e )
 {
-  QScrollView::contentsMouseReleaseEvent( e );
+  Q3ScrollView::contentsMouseReleaseEvent( e );
 
-  if ( d->mResizeAnchor && d->span ) {
+  if ( d->mResizeAnchor && d->mSpan ) {
     unsetCursor();
     // hide rubber bands
-    int newiw = d->mItemWidth - ((d->mResizeAnchor - d->mRubberBandAnchor) / d->span);
+    int newiw = d->mItemWidth - ((d->mResizeAnchor - d->mRubberBandAnchor) / d->mSpan);
     drawRubberBands( 0 );
     // we should move to reflect the new position if we are scrolled.
     if ( contentsX() ) {
-      int newX = QMAX( 0, ( d->pressed * ( newiw + d->colspace + d->mSepWidth ) ) - e->x() );
+      int newX = qMax( 0, ( d->mPressed * ( newiw + d->mColspace + d->mSepWidth ) ) - e->x() );
       setContentsPos( newX, contentsY() );
     }
     // set new item width
@@ -1123,7 +1127,7 @@ void CardView::contentsMouseReleaseEvent( QMouseEvent *e )
   }
 
   // If there are accel keys, we will not emit signals
-  if ( (e->state() & Qt::ShiftButton) || (e->state() & Qt::ControlButton) )
+  if ( (e->modifiers() & Qt::ShiftModifier) || (e->modifiers() & Qt::ControlModifier) )
     return;
 
   // Get the item at this position
@@ -1135,7 +1139,7 @@ void CardView::contentsMouseReleaseEvent( QMouseEvent *e )
 
 void CardView::contentsMouseDoubleClickEvent( QMouseEvent *e )
 {
-  QScrollView::contentsMouseDoubleClickEvent( e );
+  Q3ScrollView::contentsMouseDoubleClickEvent( e );
 
   CardViewItem *item = itemAt( e->pos() );
 
@@ -1158,7 +1162,7 @@ void CardView::contentsMouseMoveEvent( QMouseEvent *e )
       return;
   }
 
-  if ( d->mLastClickOnItem && (e->state() & Qt::LeftButton) &&
+  if ( d->mLastClickOnItem && (e->buttons() & Qt::LeftButton) &&
        ((e->pos() - d->mLastClickPos).manhattanLength() > 4)) {
 
     startDrag();
@@ -1174,10 +1178,10 @@ void CardView::contentsMouseMoveEvent( QMouseEvent *e )
     int colw = colcontentw + d->mSepWidth;
     int m = e->x() % colw;
     if ( m >= colcontentw && m > 0 ) {
-      setCursor( SplitHCursor );
+      setCursor( Qt::SplitHCursor );
       d->mOnSeparator = true;
     } else {
-      setCursor( ArrowCursor );
+      setCursor( Qt::ArrowCursor );
       d->mOnSeparator = false;
     }
   }
@@ -1193,7 +1197,7 @@ void CardView::leaveEvent( QEvent* )
   d->mTimer->stop();
   if ( d->mOnSeparator ) {
     d->mOnSeparator = false;
-    setCursor( ArrowCursor );
+    setCursor( Qt::ArrowCursor );
   }
 }
 
@@ -1223,19 +1227,19 @@ void CardView::keyPressEvent( QKeyEvent *e )
   CardViewItem *old = d->mCurrentItem;
 
   switch ( e->key() ) {
-    case Key_Up:
+    case Qt::Key_Up:
       if ( pos > 0 ) {
         aItem = d->mItemList.at( pos - 1 );
         setCurrentItem( aItem );
       }
       break;
-    case Key_Down:
+    case Qt::Key_Down:
       if ( pos < d->mItemList.count() - 1 ) {
         aItem = d->mItemList.at( pos + 1 );
         setCurrentItem( aItem );
       }
       break;
-    case Key_Left:
+    case Qt::Key_Left:
     {
       // look for an item in the previous/next column, starting from
       // the vertical middle of the current item.
@@ -1253,7 +1257,7 @@ void CardView::keyPressEvent( QKeyEvent *e )
 
       break;
     }
-    case Key_Right:
+    case Qt::Key_Right:
     {
       // FIXME use nice calculated measures!!!
       QPoint aPoint( d->mCurrentItem->d->x + d->mItemWidth, d->mCurrentItem->d->y );
@@ -1268,29 +1272,29 @@ void CardView::keyPressEvent( QKeyEvent *e )
 
       break;
     }
-    case Key_Home:
+    case Qt::Key_Home:
       aItem = d->mItemList.first();
       setCurrentItem( aItem );
       break;
-    case Key_End:
+    case Qt::Key_End:
       aItem = d->mItemList.last();
       setCurrentItem( aItem );
       break;
-    case Key_Prior: // PageUp
+    case Qt::Key_PageUp: // PageUp
     {
       // QListView: "Make the item above the top visible and current"
       // TODO if contentsY(), pick the top item of the leftmost visible column
       if ( contentsX() <= 0 )
         return;
       int cw = columnWidth();
-      int theCol = ( QMAX( 0, ( contentsX() / cw) * cw ) ) + d->mItemSpacing;
+      int theCol = ( qMax( 0, ( contentsX() / cw) * cw ) ) + d->mItemSpacing;
       aItem = itemAt( QPoint( theCol + 1, d->mItemSpacing + 1 ) );
       if ( aItem )
         setCurrentItem( aItem );
 
       break;
     }
-    case Key_Next:  // PageDown
+    case Qt::Key_PageDown:  // PageDown
     {
       // QListView: "Make the item below the bottom visible and current"
       // find the first not fully visible column.
@@ -1313,21 +1317,21 @@ void CardView::keyPressEvent( QKeyEvent *e )
 
       break;
     }
-    case Key_Space:
+    case Qt::Key_Space:
       setSelected( d->mCurrentItem, !d->mCurrentItem->isSelected() );
       emit selectionChanged();
       break;
-    case Key_Return:
-    case Key_Enter:
+    case Qt::Key_Return:
+    case Qt::Key_Enter:
       emit returnPressed( d->mCurrentItem );
       emit executed( d->mCurrentItem );
       break;
-    case Key_Menu:
-      emit contextMenuRequested( d->mCurrentItem, viewport()->mapToGlobal( 
+    case Qt::Key_Menu:
+      emit contextMenuRequested( d->mCurrentItem, viewport()->mapToGlobal(
                                  itemRect(d->mCurrentItem).center() ) );
       break;
     default:
-      if ( (e->state() & ControlButton) && e->key() == Key_A ) {
+      if ( (e->modifiers() & Qt::ControlModifier) && e->key() == Qt::Key_A ) {
         // select all
         selectAll( true );
         break;
@@ -1340,7 +1344,7 @@ void CardView::keyPressEvent( QKeyEvent *e )
   // handle selection
   if ( aItem ) {
     if ( d->mSelectionMode == CardView::Extended ) {
-      if ( e->state() & ShiftButton ) {
+      if ( e->modifiers() & Qt::ShiftModifier ) {
         // shift button: toggle range
         // if control button is pressed, leave all items
         // and toggle selection current->old current
@@ -1360,14 +1364,14 @@ void CardView::keyPressEvent( QKeyEvent *e )
         }
 
         CardViewItem *item;
-        for ( ; from <= to; from++ ) {
+        for ( ; from <= to; ++from ) {
           item = d->mItemList.at( from );
           item->setSelected( s );
           repaintItem( item );
         }
 
         emit selectionChanged();
-      } else if ( e->state() & ControlButton ) {
+      } else if ( e->modifiers() & Qt::ControlModifier ) {
         // control button: do nothing
       } else {
         // no button: move selection to this item
@@ -1469,19 +1473,19 @@ void CardView::tryShowFullText()
 
 void CardView::drawRubberBands( int pos )
 {
-  if ( pos && d &&
-       (!d->span || ((pos - d->firstX) / d->span) - d->colspace - d->mSepWidth < MIN_ITEM_WIDTH) )
+  if (!d->mSpan || ((pos - d->mFirstX) / d->mSpan) - d->mColspace - d->mSepWidth < MIN_ITEM_WIDTH)
     return;
 
-  int tmpcw = (d->mRubberBandAnchor - d->firstX) / d->span;
-  int x = d->firstX + tmpcw - d->mSepWidth - contentsX();
+  int tmpcw = (d->mRubberBandAnchor - d->mFirstX) / d->mSpan;
+  int x = d->mFirstX + tmpcw - d->mSepWidth - contentsX();
   int h = visibleHeight();
 
   QPainter p( viewport() );
-  p.setRasterOp( XorROP );
-  p.setPen( gray );
-  p.setBrush( gray );
-  uint n = d->first;
+  // FIXME porting
+  //p.setRasterOp( XorROP );
+  p.setPen( Qt::gray );
+  p.setBrush( Qt::gray );
+  uint n = d->mFirst;
   // erase
   if ( d->mRubberBandAnchor )
     do {
@@ -1492,9 +1496,9 @@ void CardView::drawRubberBands( int pos )
   // paint new
   if ( ! pos )
     return;
-  tmpcw = (pos - d->firstX) / d->span;
-  n = d->first;
-  x = d->firstX + tmpcw - d->mSepWidth - contentsX();
+  tmpcw = (pos - d->mFirstX) / d->mSpan;
+  n = d->mFirst;
+  x = d->mFirstX + tmpcw - d->mSepWidth - contentsX();
   do {
       p.drawRect( x, 0, 2, h );
       x += tmpcw;
@@ -1533,7 +1537,7 @@ QFont CardView::headerFont() const
 
 void CardView::setFont( const QFont &fnt )
 {
-  QScrollView::setFont( fnt );
+  Q3ScrollView::setFont( fnt );
   delete d->mFm;
   d->mFm = new QFontMetrics( fnt );
 }
