@@ -29,14 +29,9 @@
  *  your version.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "kmacctcachedimap.h"
 using KMail::SieveConfig;
 
-#include "kmfoldertree.h"
 #include "kmfoldermgr.h"
 #include "kmfiltermgr.h"
 #include "kmfoldercachedimap.h"
@@ -45,21 +40,21 @@ using KMail::SieveConfig;
 using KMail::AccountManager;
 #include "progressmanager.h"
 
-#include <kio/passdlg.h>
+#include <kio/passworddialog.h>
 #include <kio/scheduler.h>
 #include <kio/slave.h>
-#include <kmessagebox.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
-#include <kconfig.h>
+#include <kconfiggroup.h>
 
-#include <qstylesheet.h>
+#include <QList>
 
 KMAcctCachedImap::KMAcctCachedImap( AccountManager* aOwner,
 				    const QString& aAccountName, uint id )
   : KMail::ImapAccountBase( aOwner, aAccountName, id ), mFolder( 0 ),
-    mAnnotationCheckPassed(false)
+    mAnnotationCheckPassed(false),
+    mGroupwareType( GroupwareKolab ),
+    mSentCustomLoginCommand(false)
 {
   // Never EVER set this for the cached IMAP account
   mAutoExpunge = false;
@@ -74,11 +69,6 @@ KMAcctCachedImap::~KMAcctCachedImap()
 
 
 //-----------------------------------------------------------------------------
-QString KMAcctCachedImap::type() const
-{
-  return "cachedimap";
-}
-
 void KMAcctCachedImap::init() {
   ImapAccountBase::init();
 }
@@ -113,30 +103,30 @@ void KMAcctCachedImap::setAutoExpunge( bool /*aAutoExpunge*/ )
 //-----------------------------------------------------------------------------
 void KMAcctCachedImap::killAllJobs( bool disconnectSlave )
 {
-  //kdDebug(5006) << "killAllJobs: disconnectSlave=" << disconnectSlave << "  " << mapJobData.count() << " jobs in map." << endl;
-  QValueList<KMFolderCachedImap*> folderList = killAllJobsInternal( disconnectSlave );
-  for( QValueList<KMFolderCachedImap*>::Iterator it = folderList.begin(); it != folderList.end(); ++it ) {
+  //kDebug(5006) <<"killAllJobs: disconnectSlave=" << disconnectSlave << mapJobData.count() <<" jobs in map.";
+  QList<KMFolderCachedImap*> folderList = killAllJobsInternal( disconnectSlave );
+  for( QList<KMFolderCachedImap*>::Iterator it = folderList.begin(); it != folderList.end(); ++it ) {
     KMFolderCachedImap *fld = *it;
     fld->resetSyncState();
     fld->setContentState(KMFolderCachedImap::imapNoInformation);
     fld->setSubfolderState(KMFolderCachedImap::imapNoInformation);
-    fld->sendFolderComplete(FALSE);
+    fld->sendFolderComplete(false);
   }
 }
 
 //-----------------------------------------------------------------------------
 // Common between killAllJobs and the destructor - which shouldn't call sendFolderComplete
-QValueList<KMFolderCachedImap*> KMAcctCachedImap::killAllJobsInternal( bool disconnectSlave )
+QList<KMFolderCachedImap*> KMAcctCachedImap::killAllJobsInternal( bool disconnectSlave )
 {
   // Make list of folders to reset. This must be done last, since folderComplete
   // can trigger the next queued mail check already.
-  QValueList<KMFolderCachedImap*> folderList;
-  QMap<KIO::Job*, jobData>::Iterator it = mapJobData.begin();
+  QList<KMFolderCachedImap*> folderList;
+  QMap<KJob*, jobData>::Iterator it = mapJobData.begin();
   for (; it != mapJobData.end(); ++it) {
     if ((*it).parent)
       folderList << static_cast<KMFolderCachedImap*>((*it).parent->storage());
     // Kill the job - except if it's the one that already died and is calling us
-    if ( !it.key()->error() && mSlave ) {
+    if ( mSlave && !it.key()->error() ) {
       it.key()->kill();
       mSlave = 0; // killing a job, kills the slave
     }
@@ -144,8 +134,9 @@ QValueList<KMFolderCachedImap*> KMAcctCachedImap::killAllJobsInternal( bool disc
   mapJobData.clear();
 
   // Clear the joblist. Make SURE to stop the job emitting "finished"
-  for( QPtrListIterator<CachedImapJob> it( mJobList ); it.current(); ++it )
-    it.current()->setPassiveDestructor( true );
+  QList<CachedImapJob*>::const_iterator jt;
+  for( jt = mJobList.constBegin(); jt != mJobList.constEnd(); ++jt )
+    (*jt)->setPassiveDestructor( true );
   KMAccount::deleteFolderJobs();
 
   if ( disconnectSlave && mSlave ) {
@@ -159,8 +150,8 @@ QValueList<KMFolderCachedImap*> KMAcctCachedImap::killAllJobsInternal( bool disc
 void KMAcctCachedImap::cancelMailCheck()
 {
   // Make list of folders to reset, like in killAllJobs
-  QValueList<KMFolderCachedImap*> folderList;
-  QMap<KIO::Job*, jobData>::Iterator it = mapJobData.begin();
+  QList<KMFolderCachedImap*> folderList;
+  QMap<KJob*, jobData>::Iterator it = mapJobData.begin();
   for (; it != mapJobData.end(); ++it) {
     if ( (*it).cancellable && (*it).parent )
       folderList << static_cast<KMFolderCachedImap*>((*it).parent->storage());
@@ -169,22 +160,24 @@ void KMAcctCachedImap::cancelMailCheck()
   ImapAccountBase::cancelMailCheck();
   // Reset sync states and emit folderComplete, this is important for
   // KMAccount::checkingMail() to be reset, in case we restart checking mail later.
-  for( QValueList<KMFolderCachedImap*>::Iterator it = folderList.begin(); it != folderList.end(); ++it ) {
+  for( QList<KMFolderCachedImap*>::Iterator it = folderList.begin(); it != folderList.end(); ++it ) {
     KMFolderCachedImap *fld = *it;
     fld->resetSyncState();
     fld->setContentState(KMFolderCachedImap::imapNoInformation);
     fld->setSubfolderState(KMFolderCachedImap::imapNoInformation);
-    fld->sendFolderComplete(FALSE);
+    fld->sendFolderComplete(false);
   }
 }
 
+/*
+  This is never called from anywhere
 //-----------------------------------------------------------------------------
 void KMAcctCachedImap::killJobsForItem(KMFolderTreeItem * fti)
 {
-  QMap<KIO::Job *, jobData>::Iterator it = mapJobData.begin();
+  QMap<KJob *, jobData>::Iterator it = mapJobData.begin();
   while (it != mapJobData.end())
   {
-    if (it.data().parent == fti->folder())
+    if (it.value().parent == fti->folder())
     {
       killAllJobs();
       break;
@@ -192,6 +185,7 @@ void KMAcctCachedImap::killJobsForItem(KMFolderTreeItem * fti)
     else ++it;
   }
 }
+*/
 
 // Reimplemented from ImapAccountBase because we only check one folder at a time
 void KMAcctCachedImap::slotCheckQueuedFolders()
@@ -209,7 +203,7 @@ void KMAcctCachedImap::slotCheckQueuedFolders()
 
 void KMAcctCachedImap::processNewMail( bool /*interactive*/ )
 {
-  assert( mFolder );  // George says "better to crash then lose mail"
+  assert( mFolder );
 
   if ( mMailCheckFolders.isEmpty() )
     processNewMail( mFolder, true );
@@ -223,8 +217,7 @@ void KMAcctCachedImap::processNewMail( bool /*interactive*/ )
 void KMAcctCachedImap::processNewMail( KMFolderCachedImap* folder,
                                        bool recurse )
 {
-  assert( folder ); // George says "better to crash then lose mail"
-
+  assert( folder );
   // This should never be set for a cached IMAP account
   mAutoExpunge = false;
   mCountLastUnread = 0;
@@ -251,9 +244,9 @@ void KMAcctCachedImap::processNewMail( KMFolderCachedImap* folder,
   Q_ASSERT( !mMailCheckProgressItem );
   mMailCheckProgressItem = KPIM::ProgressManager::createProgressItem(
     "MailCheck" + QString::number( id() ),
-    QStyleSheet::escape( folder->label() ), // will be changed immediately in serverSync anyway
-    QString::null,
-    true, // can be cancelled
+    folder->label(), // will be changed immediately in serverSync anyway
+    QString(),
+    true, // can be canceled
     useSSL() || useTLS() );
   connect( mMailCheckProgressItem, SIGNAL( progressItemCanceled( KPIM::ProgressItem* ) ),
            this, SLOT( slotProgressItemCanceled( KPIM::ProgressItem* ) ) );
@@ -296,7 +289,7 @@ void KMAcctCachedImap::addUnreadMsgCount( const KMFolderCachedImap *folder,
     // therefore doesn't need to be counted here
     const QString folderId = folder->folder()->idString();
     int newInFolder = countUnread;
-    if ( mUnreadBeforeCheck.find( folderId ) != mUnreadBeforeCheck.end() )
+    if ( mUnreadBeforeCheck.contains( folderId )  )
       newInFolder -= mUnreadBeforeCheck[folderId];
     if ( newInFolder > 0 )
       addToNewInFolder( folderId, newInFolder );
@@ -317,30 +310,32 @@ void KMAcctCachedImap::addLastUnreadMsgCount( const KMFolderCachedImap *folder,
 //
 //
 
-void KMAcctCachedImap::readConfig( /*const*/ KConfig/*Base*/ & config ) {
+void KMAcctCachedImap::readConfig( KConfigGroup & config ) {
   ImapAccountBase::readConfig( config );
   // Apparently this method is only ever called once (from KMKernel::init) so this is ok
-  mPreviouslyDeletedFolders = config.readListEntry( "deleted-folders" );
+  mPreviouslyDeletedFolders = config.readEntry( "deleted-folders", QStringList() );
   mDeletedFolders.clear(); // but just in case...
-  const QStringList oldPaths = config.readListEntry( "renamed-folders-paths" );
-  const QStringList newNames = config.readListEntry( "renamed-folders-names" );
+  const QStringList oldPaths = config.readEntry( "renamed-folders-paths", QStringList() );
+  const QStringList newNames = config.readEntry( "renamed-folders-names", QStringList() );
   QStringList::const_iterator it = oldPaths.begin();
   QStringList::const_iterator nameit = newNames.begin();
   for( ; it != oldPaths.end() && nameit != newNames.end(); ++it, ++nameit ) {
-    addRenamedFolder( *it, QString::null, *nameit );
+    addRenamedFolder( *it, QString(), *nameit );
   }
+  mGroupwareType = (GroupwareType)config.readEntry( "groupwareType", (int)GroupwareKolab );
 }
 
-void KMAcctCachedImap::writeConfig( KConfig/*Base*/ & config ) /*const*/ {
+void KMAcctCachedImap::writeConfig( KConfigGroup & config ) {
   ImapAccountBase::writeConfig( config );
   config.writeEntry( "deleted-folders", mDeletedFolders + mPreviouslyDeletedFolders );
   config.writeEntry( "renamed-folders-paths", mRenamedFolders.keys() );
-  const QValueList<RenamedFolder> values = mRenamedFolders.values();
+  const QList<RenamedFolder> values = mRenamedFolders.values();
   QStringList lstNames;
-  QValueList<RenamedFolder>::const_iterator it = values.begin();
+  QList<RenamedFolder>::const_iterator it = values.begin();
   for ( ; it != values.end() ; ++it )
     lstNames.append( (*it).mNewName );
   config.writeEntry( "renamed-folders-names", lstNames );
+  config.writeEntry( "groupwareType", (int)mGroupwareType );
 }
 
 void KMAcctCachedImap::invalidateIMAPFolders()
@@ -356,11 +351,11 @@ void KMAcctCachedImap::invalidateIMAPFolders( KMFolderCachedImap* folder )
   folder->setAccount(this);
 
   QStringList strList;
-  QValueList<QGuardedPtr<KMFolder> > folderList;
+  QList<QPointer<KMFolder> > folderList;
   kmkernel->dimapFolderMgr()->createFolderList( &strList, &folderList,
-						folder->folder()->child(), QString::null,
+						folder->folder()->child(), QString(),
 						false );
-  QValueList<QGuardedPtr<KMFolder> >::Iterator it;
+  QList<QPointer<KMFolder> >::Iterator it;
   mCountLastUnread = 0;
   mUnreadBeforeCheck.clear();
 
@@ -387,16 +382,18 @@ void KMAcctCachedImap::addDeletedFolder( KMFolder* folder )
     return;
   KMFolderCachedImap* storage = static_cast<KMFolderCachedImap*>(folder->storage());
   addDeletedFolder( storage->imapPath() );
-  kdDebug(5006) << k_funcinfo << storage->imapPath() << endl;
+  kDebug(5006) << storage->imapPath();
 
   // Add all child folders too
   if( folder->child() ) {
-    KMFolderNode *node = folder->child()->first();
-    while( node ) {
-      if( !node->isDir() ) {
+    QList<KMFolderNode*>::const_iterator it;
+    for ( it = folder->child()->constBegin();
+        it != folder->child()->constEnd();
+        ++it ) {
+      KMFolderNode *node = (*it);
+      if( node && !node->isDir() ) {
         addDeletedFolder( static_cast<KMFolder*>( node ) ); // recurse
       }
-      node = folder->child()->next();
     }
   }
 }
@@ -418,25 +415,25 @@ QStringList KMAcctCachedImap::deletedFolderPaths( const QString& subFolderPath )
     if ( (*it).startsWith( subFolderPath ) )
       lst.prepend( *it );
   }
-  kdDebug(5006) << "KMAcctCachedImap::deletedFolderPaths for " << subFolderPath << " returning: " << lst << endl;
+  kDebug(5006) << "For" << subFolderPath <<" returning:" << lst;
   Q_ASSERT( !lst.isEmpty() );
   return lst;
 }
 
 bool KMAcctCachedImap::isDeletedFolder( const QString& subFolderPath ) const
 {
-  return mDeletedFolders.find( subFolderPath ) != mDeletedFolders.end();
+  return mDeletedFolders.contains( subFolderPath ) ;
 }
 
 bool KMAcctCachedImap::isPreviouslyDeletedFolder( const QString& subFolderPath ) const
 {
-  return mPreviouslyDeletedFolders.find( subFolderPath ) != mPreviouslyDeletedFolders.end();
+  return mPreviouslyDeletedFolders.contains( subFolderPath ) ;
 }
 
 void KMAcctCachedImap::removeDeletedFolder( const QString& subFolderPath )
 {
-  mDeletedFolders.remove( subFolderPath );
-  mPreviouslyDeletedFolders.remove( subFolderPath );
+  mDeletedFolders.removeAll( subFolderPath );
+  mPreviouslyDeletedFolders.removeAll( subFolderPath );
 }
 
 void KMAcctCachedImap::addRenamedFolder( const QString& subFolderPath, const QString& oldLabel, const QString& newName )
@@ -455,11 +452,11 @@ void KMAcctCachedImap::slotProgressItemCanceled( ProgressItem* )
   killAllJobs( abortConnection );
   if ( abortConnection ) {
     // If we were trying to connect, tell kmfoldercachedimap so that it moves on
-    emit connectionResult( KIO::ERR_USER_CANCELED, QString::null );
+    emit connectionResult( KIO::ERR_USER_CANCELED, QString() );
   }
 }
 
-FolderStorage* const KMAcctCachedImap::rootFolder() const
+FolderStorage* KMAcctCachedImap::rootFolder() const
 {
   return mFolder;
 }
@@ -470,7 +467,7 @@ QString KMAcctCachedImap::renamedFolder( const QString& imapPath ) const
   QMap<QString, RenamedFolder>::ConstIterator renit = mRenamedFolders.find( imapPath );
   if ( renit != mRenamedFolders.end() )
     return (*renit).mNewName;
-  return QString::null;
+  return QString();
 }
 
 #include "kmacctcachedimap.moc"
