@@ -30,34 +30,33 @@
 #include <libkdepim/ktimezonecombobox.h>
 
 #include <kcal/todo.h>
+#include <kcal/incidenceformatter.h>
 
 #include <kglobal.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
-#include <kfiledialog.h>
 #include <ktextedit.h>
 #include <KComboBox>
 #include <KRichTextWidget>
 
-#include <QLayout>
-#include <QDateTime>
-#include <QCheckBox>
-#include <QLabel>
-#include <QSpinBox>
-#include <QPushButton>
-#include <QGroupBox>
-#include <QGridLayout>
-#include <QFrame>
-#include <QHBoxLayout>
 #include <QBoxLayout>
+#include <QCheckBox>
+#include <QDateTime>
+#include <KDialog>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QPushButton>
+#include <QSpinBox>
 #include <QVBoxLayout>
 
 #include "koeditorgeneraltodo.moc"
 
-KOEditorGeneralTodo::KOEditorGeneralTodo( QObject *parent )
-  : KOEditorGeneral( parent )
+KOEditorGeneralTodo::KOEditorGeneralTodo( Calendar *calendar, QObject *parent )
+  : KOEditorGeneral( calendar, parent )
 {
 }
 
@@ -106,12 +105,18 @@ void KOEditorGeneralTodo::initTime( QWidget *parent, QBoxLayout *topLayout )
 
   // Timezone
   QString whatsThis = i18n( "Select the timezone for this event. It will also affect recurrences" );
-  mTimeZoneComboStart = new KPIM::KTimeZoneComboBox( timeGroupBox );
-  mTimeZoneComboDue = new KPIM::KTimeZoneComboBox( timeGroupBox );
+  mTimeZoneComboStart = new KPIM::KTimeZoneComboBox( mCalendar, timeGroupBox );
+  mTimeZoneComboDue = new KPIM::KTimeZoneComboBox( mCalendar, timeGroupBox );
+  if ( !KOPrefs::instance()->showTimeZoneSelectorInIncidenceEditor() ) {
+    mTimeZoneComboStart->hide();
+    mTimeZoneComboDue->hide();
+  }
   layoutTimeBox->addWidget( mTimeZoneComboStart, 0, 3 );
   layoutTimeBox->addWidget( mTimeZoneComboDue, 1, 3 );
   mTimeZoneComboStart->setWhatsThis( whatsThis );
   mTimeZoneComboDue->setWhatsThis( whatsThis );
+  mTimeZoneComboStart->selectLocalTimeSpec();
+  mTimeZoneComboDue->selectLocalTimeSpec();
 
   whatsThis = i18n( "Sets the start date for this to-do" );
   mStartCheck = new QCheckBox( i18nc( "@option:check to-do start datetime",
@@ -188,10 +193,12 @@ void KOEditorGeneralTodo::initCompletion( QWidget *parent, QBoxLayout *topLayout
   topLayout->addWidget( mCompletedLabel );
   mCompletedLabel->setBuddy( mCompletedCombo );
   mCompletionDateEdit = new KPIM::KDateEdit( parent );
+  mCompletionDateEdit->hide();
   topLayout->addWidget( mCompletionDateEdit );
   mCompletionTimeEdit = new KPIM::KTimeEdit( parent, QTime() );
+  mCompletionTimeEdit->hide();
   topLayout->addWidget( mCompletionTimeEdit );
-  if ( !(mCompletedCombo->currentIndex() == 10 && mCompleted.isValid() )) {
+  if ( !( mCompletedCombo->currentIndex() == 10 && mCompleted.isValid() ) ) {
     mCompletedLabel->setText( i18nc( "to-do completed", "co&mpleted" ) );
     mCompletionDateEdit->hide();
     mCompletionTimeEdit->hide();
@@ -273,9 +280,12 @@ void KOEditorGeneralTodo::setDefaults( const QDateTime &due, bool allDay )
   mCompletedCombo->setCurrentIndex( 0 );
 }
 
-void KOEditorGeneralTodo::readTodo( Todo *todo, Calendar *calendar )
+void KOEditorGeneralTodo::readTodo( Todo *todo, bool tmpl )
 {
-  KOEditorGeneral::readIncidence( todo, calendar );
+  //TODO: do something with tmpl
+  Q_UNUSED( tmpl );
+
+  KOEditorGeneral::readIncidence( todo );
 
   QDateTime dueDT;
 
@@ -294,6 +304,7 @@ void KOEditorGeneralTodo::readTodo( Todo *todo, Calendar *calendar )
     mDueDateEdit->setDate( QDate::currentDate() );
     mDueTimeEdit->setTime( QTime::currentTime() );
     mDueCheck->setChecked( false );
+    mTimeZoneComboDue->setEnabled( false );
   }
 
   if ( todo->hasStartDate() ) {
@@ -309,6 +320,7 @@ void KOEditorGeneralTodo::readTodo( Todo *todo, Calendar *calendar )
     mStartDateEdit->setDate( QDate::currentDate() );
     mStartTimeEdit->setTime( QTime::currentTime() );
     mStartCheck->setChecked( false );
+    mTimeZoneComboStart->setEnabled( false );
   }
 
   mTimeButton->setChecked( !todo->allDay() );
@@ -325,9 +337,9 @@ void KOEditorGeneralTodo::readTodo( Todo *todo, Calendar *calendar )
   mStartDateModified = false;
 }
 
-void KOEditorGeneralTodo::writeTodo( Todo *todo )
+void KOEditorGeneralTodo::fillTodo( Todo *todo )
 {
-  KOEditorGeneral::writeIncidence( todo );
+  KOEditorGeneral::fillIncidence( todo );
 
   // temp. until something better happens.
   QString tmpStr;
@@ -341,6 +353,9 @@ void KOEditorGeneralTodo::writeTodo( Todo *todo )
   QDate tmpSDate, tmpDDate;
   QTime tmpSTime, tmpDTime;
   KDateTime tmpStartDT, tmpDueDT;
+  tmpDueDT.setTimeSpec( dueSpec );
+  tmpStartDT.setTimeSpec( startSpec );
+
   if ( mTimeButton->isChecked() ) {
     todo->setAllDay( false );
 
@@ -349,7 +364,6 @@ void KOEditorGeneralTodo::writeTodo( Todo *todo )
     tmpDTime = mDueTimeEdit->getTime();
     tmpDueDT.setDate( tmpDDate );
     tmpDueDT.setTime( tmpDTime );
-    tmpDueDT.setTimeSpec( dueSpec );
 
     // set start date/time
     if ( mStartCheck->isChecked() ) {
@@ -357,7 +371,6 @@ void KOEditorGeneralTodo::writeTodo( Todo *todo )
       tmpSTime = mStartTimeEdit->getTime();
       tmpStartDT.setDate( tmpSDate );
       tmpStartDT.setTime( tmpSTime );
-      tmpStartDT.setTimeSpec( startSpec );
     } else {
       tmpStartDT = tmpDueDT;
     }
@@ -471,12 +484,14 @@ bool KOEditorGeneralTodo::validateInput()
 {
   if ( mDueCheck->isChecked() ) {
     if ( !mDueDateEdit->date().isValid() ) {
-      KMessageBox::sorry( 0, i18n( "Please specify a valid due date." ) );
+      KMessageBox::sorry( mParent,
+                          i18n( "Please specify a valid due date." ) );
       return false;
     }
     if ( mTimeButton->isChecked() ) {
       if ( !mDueTimeEdit->inputIsValid() ) {
-        KMessageBox::sorry( 0, i18n( "Please specify a valid due time." ) );
+        KMessageBox::sorry( mParent,
+                            i18n( "Please specify a valid due time." ) );
         return false;
       }
     }
@@ -484,12 +499,14 @@ bool KOEditorGeneralTodo::validateInput()
 
   if ( mStartCheck->isChecked() ) {
     if ( !mStartDateEdit->date().isValid() ) {
-      KMessageBox::sorry( 0, i18n( "Please specify a valid start date." ) );
+      KMessageBox::sorry( mParent,
+                          i18n( "Please specify a valid start date." ) );
       return false;
     }
     if ( mTimeButton->isChecked() ) {
       if ( !mStartTimeEdit->inputIsValid() ) {
-        KMessageBox::sorry( 0, i18n( "Please specify a valid start time." ) );
+        KMessageBox::sorry( mParent,
+                            i18n( "Please specify a valid start time." ) );
         return false;
       }
     }
@@ -505,7 +522,8 @@ bool KOEditorGeneralTodo::validateInput()
       dueDate.setTime( mDueTimeEdit->getTime() );
     }
     if ( startDate > dueDate ) {
-      KMessageBox::sorry( 0, i18n( "The start date cannot be after the due date." ) );
+      KMessageBox::sorry( mParent,
+                          i18n( "The start date cannot be after the due date." ) );
       return false;
     }
   }
@@ -531,7 +549,7 @@ void KOEditorGeneralTodo::dateChanged()
                           "Start: %1", l->formatDate( mStartDateEdit->date() ) );
     if ( mTimeButton->isChecked() ) {
       dateTimeStr += QString( " %1" ).arg( l->formatTime( mStartTimeEdit->getTime() ) );
-
+      dateTimeStr += ' ';
       dateTimeStr += mTimeZoneComboStart->selectedTimeSpec().timeZone().name();
     }
   }
@@ -541,6 +559,7 @@ void KOEditorGeneralTodo::dateChanged()
                           l->formatDate( mDueDateEdit->date() ) );
     if ( mTimeButton->isChecked() ) {
       dateTimeStr += QString( " %1" ).arg( l->formatTime( mDueTimeEdit->getTime() ) );
+      dateTimeStr += ' ';
       dateTimeStr += mTimeZoneComboDue->selectedTimeSpec().timeZone().name();
     }
   }
@@ -594,7 +613,7 @@ void KOEditorGeneralTodo::modified( Todo *todo, int modification )
     break;
   case KOGlobals::UNKNOWN_MODIFIED: // fall through
   default:
-    readTodo( todo, 0 );
+    readTodo( todo );
     break;
   }
 }
