@@ -1,6 +1,6 @@
 /* KPilot
 **
-** Copyright (C) 1998-2001 by Dan Pilone
+** Copyright (C) 1998-2001 by Dan Pilone <dan@kpilot.org>
 ** Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 ** Copyright (C) 2006-2007 Adriaan de Groot <groot@kde.org>
 ** Copyright (C) 2007 Jason 'vanRijn' Kasper <vR@movingparts.net>
@@ -28,43 +28,45 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
+// KPilot headers
+#include "kpilotlink.moc"
 #include "options.h"
+#include "pilotCard.h"
+#include "pilotUser.h"
+#include "pilotSerialDatabase.h"
+#include "pilotLocalDatabase.h"
+#include "pilotSysInfo.h"
 
-
-
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <errno.h>
-
-#include <iostream>
-
-#include <pi-source.h>
-#include <pi-socket.h>
+// pilot-link headers
+#include <pi-buffer.h>
 #include <pi-dlp.h>
 #include <pi-file.h>
-#include <pi-buffer.h>
+#include <pi-source.h>
+#include <pi-socket.h>
 
-#include <qdir.h>
-#include <qtimer.h>
-#include <qdatetime.h>
-#include <qthread.h>
+// Qt headers
+#include <QtCore/QDir>
+#include <QtCore/QDateTime>
+#include <QtCore/QEvent>
+#include <QtCore/QThread>
+#include <QtCore/QTimer>
+#include <QtGui/QApplication>
 
+// KDE headers
 #include <kconfig.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
 #include <kio/netaccess.h>
 
-#include "pilotUser.h"
-#include "pilotSysInfo.h"
-#include "pilotCard.h"
-#include "pilotSerialDatabase.h"
-#include "pilotLocalDatabase.h"
-
-#include "kpilotlink.moc"
+// other headers
+#include <errno.h>
+#include <fcntl.h>
+#include <iostream>
+#include <stdio.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 /** Class that handles periodically tickling the handheld through
 *   the virtual tickle() method; deals with cancels through the
@@ -98,13 +100,12 @@ TickleThread::~TickleThread()
 
 void TickleThread::run()
 {
-	FUNCTIONSETUP;
+	FUNCTIONSETUPL(5);
 	int subseconds = ChecksPerSecond;
 	int ticktock = SecondsPerTickle;
 	int timeout = fTimeout;
-	DEBUGKPILOT << fname << ": Running for "
-		<< timeout << " seconds." << endl;
-	DEBUGKPILOT << fname << ": Done @" << (void *) fDone << endl;
+	DEBUGKPILOT << "Running for" << timeout << " seconds.";
+	DEBUGKPILOT << "Done @" << (void *) fDone;
 
 	while (!(*fDone))
 	{
@@ -115,7 +116,8 @@ void TickleThread::run()
 			{
 				if (!(--timeout))
 				{
-					QApplication::postEvent(fHandle, new QCustomEvent(static_cast<QEvent::Type>(KPilotLink::EventTickleTimeout)));
+					DEBUGKPILOT << "posting timeout event.";
+					QApplication::postEvent(fHandle, new QEvent(static_cast<QEvent::Type>(KPilotLink::EventTickleTimeout)));
 					break;
 				}
 			}
@@ -123,6 +125,7 @@ void TickleThread::run()
 			if (!(--ticktock))
 			{
 				ticktock=SecondsPerTickle;
+				DEBUGKPILOT << "sending tickle from tickle thread.";
 				fHandle->tickle();
 			}
 		}
@@ -138,8 +141,8 @@ void TickleThread::run()
 
 
 KPilotLink::KPilotLink( QObject *parent, const char *name ) :
-	QObject( parent, name ),
-	fPilotPath(QString::null),
+	QObject( parent ),
+	fPilotPath(QString()),
 	fPilotUser(0L),
 	fPilotSysInfo(0L),
 	fTickleDone(true),
@@ -148,6 +151,11 @@ KPilotLink::KPilotLink( QObject *parent, const char *name ) :
 {
 	FUNCTIONSETUP;
 
+	if (name)
+	{
+		setObjectName(name);
+	}
+
 	fPilotUser = new KPilotUser();
 	strncpy( fPilotUser->data()->username, "Henk Westbroek",
 		sizeof(fPilotUser->data()->username)-1);
@@ -169,13 +177,15 @@ KPilotLink::~KPilotLink()
 	KPILOT_DELETE(fPilotSysInfo);
 }
 
-void KPilotLink::customEvent(QCustomEvent *e)
+/* virtual */ bool KPilotLink::event(QEvent *e)
 {
 	if ((int)e->type() == EventTickleTimeout)
 	{
 		stopTickle();
 		emit timeout();
+      return true;
 	}
+   else return QObject::event(e);
 }
 
 /*
@@ -185,20 +195,12 @@ void KPilotLink::startTickle(unsigned int timeout)
 {
 	FUNCTIONSETUP;
 
-	Q_ASSERT(fTickleDone);
-
-	/*
-	** We've told the thread to finish up, but it hasn't
-	** done so yet - so wait for it to do so, should be
-	** only 200ms at most.
-	*/
-	if (fTickleDone && fTickleThread)
+	if (fTickleThread)
 	{
-		fTickleThread->wait();
-		KPILOT_DELETE(fTickleThread);
+		stopTickle();
 	}
 
-	DEBUGKPILOT << fname << ": Done @" << (void *) (&fTickleDone) << endl;
+	DEBUGKPILOT << "Done @" << (void *) (&fTickleDone);
 
 	fTickleDone = false;
 	fTickleThread = new TickleThread(this,&fTickleDone,timeout);
@@ -227,14 +229,14 @@ unsigned int KPilotLink::installFiles(const QStringList & l, const bool deleteFi
 
 	for (i = l.begin(), e = l.end(); i != e; ++i)
 	{
-		emit logProgress(QString::null,
+		emit logProgress(QString(),
 			(int) ((100.0 / total) * (float) n));
 
 		if (installFile(*i, deleteFiles))
 			k++;
 		n++;
 	}
-	emit logProgress(QString::null, 100);
+	emit logProgress(QString(), 100);
 
 	return k;
 }
