@@ -19,48 +19,49 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <qbuffer.h>
-#include <qimage.h>
-#include <qpopupmenu.h>
-#include <qurl.h>
+#include "addresseeview.h"
+#include "sendsmsdialog.h"
 
 #include <kabc/address.h>
 #include <kabc/addressee.h>
 #include <kabc/phonenumber.h>
-#include <kactionclasses.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <kiconloader.h>
+#include <kabc/resource.h>
+#include <kabc/resourceabc.h>
+
+#include <KApplication>
+#include <KCodecs>
+#include <KColorScheme>
+#include <KConfig>
+#include <KDebug>
+#include <KGlobal>
+#include <KGlobalSettings>
+#include <KIconLoader>
+#include <KLocale>
+#include <KMessageBox>
+#include <KRun>
+#include <KStringHandler>
+#include <KTemporaryFile>
+#include <KToggleAction>
+#include <KToolInvocation>
+#include <KUrl>
 #include <kio/job.h>
-#include <klocale.h>
-#include <kmdcodec.h>
-#include <kmessagebox.h>
-#include <krun.h>
-#include <kstringhandler.h>
-#include <ktempfile.h>
 
-#include <kdebug.h>
-
-#include "addresseeview.h"
-#include "sendsmsdialog.h"
+#include <QBuffer>
+#include <QContextMenuEvent>
+#include <QImage>
+#include <QMenu>
+#include <QPixmap>
+#include <QTextStream>
 
 using namespace KPIM;
 
-AddresseeView::AddresseeView( QWidget *parent, const char *name,
-                              KConfig *config )
-  : KTextBrowser( parent, name ), mDefaultConfig( false ), mImageJob( 0 ),
+AddresseeView::AddresseeView( QWidget *parent, KConfig *config )
+  : KTextBrowser( parent ), mDefaultConfig( false ), mImageJob( 0 ),
     mLinkMask( AddressLinks | EmailLinks | PhoneLinks | URLLinks | IMLinks | CustomFields )
 {
-  setWrapPolicy( QTextEdit::AtWordBoundary );
-  setLinkUnderline( false );
-  setVScrollBarMode( QScrollView::AlwaysOff );
-  setHScrollBarMode( QScrollView::AlwaysOff );
-
-  QStyleSheet *sheet = styleSheet();
-  QStyleSheetItem *link = sheet->item( "a" );
-  link->setColor( KGlobalSettings::linkColor() );
+  setWordWrapMode( QTextOption::WrapAtWordBoundaryOrAnywhere );
+  setHorizontalScrollBarPolicy ( Qt::ScrollBarAlwaysOff );
+  setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
 
   connect( this, SIGNAL( mailClick( const QString&, const QString& ) ),
            this, SLOT( slotMailClicked( const QString&, const QString& ) ) );
@@ -71,20 +72,22 @@ AddresseeView::AddresseeView( QWidget *parent, const char *name,
 
   setNotifyClick( true );
 
-  mActionShowBirthday = new KToggleAction( i18n( "Show Birthday" ) );
-  mActionShowBirthday->setCheckedState( i18n( "Hide Birthday" ) );
-  mActionShowAddresses = new KToggleAction( i18n( "Show Postal Addresses" ) );
-  mActionShowAddresses->setCheckedState( i18n( "Hide Postal Addresses" ) );
-  mActionShowEmails = new KToggleAction( i18n( "Show Email Addresses" ) );
-  mActionShowEmails->setCheckedState( i18n( "Hide Email Addresses" ) );
-  mActionShowPhones = new KToggleAction( i18n( "Show Telephone Numbers" ) );
-  mActionShowPhones->setCheckedState( i18n( "Hide Telephone Numbers" ) );
-  mActionShowURLs = new KToggleAction( i18n( "Show Web Pages (URLs)" ) );
-  mActionShowURLs->setCheckedState( i18n( "Hide Web Pages (URLs)" ) );
-  mActionShowIMAddresses = new KToggleAction( i18n( "Show Instant Messaging Addresses" ) );
-  mActionShowIMAddresses->setCheckedState( i18n( "Hide Instant Messaging Addresses" ) );
-  mActionShowCustomFields = new KToggleAction( i18n( "Show Custom Fields" ) );
-  mActionShowCustomFields->setCheckedState( i18n( "Hide Custom Fields" ) );
+  mActionShowBirthday = new KToggleAction( i18n( "Show Birthday" ), this );
+  mActionShowAddresses = new KToggleAction( i18n( "Show Postal Addresses" ), this );
+  mActionShowEmails = new KToggleAction( i18n( "Show Email Addresses" ), this );
+  mActionShowPhones = new KToggleAction( i18n( "Show Telephone Numbers" ), this );
+  mActionShowURLs = new KToggleAction( i18n( "Show Web Pages (URLs)" ), this );
+  mActionShowIMAddresses = new KToggleAction( i18n( "Show Instant Messaging Addresses" ), this );
+  mActionShowCustomFields = new KToggleAction( i18n( "Show Custom Fields" ), this );
+
+  if ( !config ) {
+    mConfig = new KConfig( "kaddressbookrc" );
+    mDefaultConfig = true;
+  } else {
+    mConfig = config;
+  }
+
+  load();
 
   connect( mActionShowBirthday, SIGNAL( toggled( bool ) ), SLOT( configChanged() ) );
   connect( mActionShowAddresses, SIGNAL( toggled( bool ) ), SLOT( configChanged() ) );
@@ -94,16 +97,8 @@ AddresseeView::AddresseeView( QWidget *parent, const char *name,
   connect( mActionShowIMAddresses, SIGNAL( toggled( bool ) ), SLOT( configChanged() ) );
   connect( mActionShowCustomFields, SIGNAL( toggled( bool ) ), SLOT( configChanged() ) );
 
-  if ( !config ) {
-    mConfig = new KConfig( "kaddressbookrc" );
-    mDefaultConfig = true;
-  } else
-    mConfig = config;
-
-  load();
-
   // set up IMProxy to display contacts' IM presence and make connections to keep the display live
-  mKIMProxy = ::KIMProxy::instance( kapp->dcopClient() );
+  mKIMProxy = ::KIMProxy::instance();
   connect( mKIMProxy, SIGNAL( sigContactPresenceChanged( const QString& ) ),
            this, SLOT( slotPresenceChanged( const QString& ) ) );
   connect( mKIMProxy, SIGNAL( sigPresenceInfoExpired() ),
@@ -146,7 +141,7 @@ void AddresseeView::enableLinks( int linkMask )
   mLinkMask = linkMask;
 }
 
-QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *proxy, LinkMask linkMask,
+QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy*, LinkMask linkMask,
                                     bool internalLoading, FieldMask fieldMask )
 {
   QString image = QString( "contact_%1_image" ).arg( addr.uid() );
@@ -158,17 +153,13 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
   // placeholder where we fill in something else (in this case,
   // the global background color).
   //
-  QString backgroundColor = KGlobalSettings::alternateBackgroundColor().name();
   QString cellStyle = QString::fromLatin1(
         "style=\""
         "padding-right: 2px; "
-        "border-right: #000 dashed 1px; "
-        "background: %1;\"").arg(backgroundColor);
-  QString backgroundColor2 = KGlobalSettings::baseColor().name();
+        "border-right: #000 dashed 1px;\"" );
   QString cellStyle2 = QString::fromLatin1(
         "style=\""
-        "padding-left: 2px; "
-        "background: %1;\"").arg(backgroundColor2);
+        "padding-left: 2px;\"" );
   QString tableStyle = QString::fromLatin1(
         "style=\""
         "border: solid 1px; "
@@ -201,11 +192,11 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
   if ( !internalLoading ) {
     KABC::Picture pic = addr.photo();
     if ( pic.isIntern() && !pic.data().isNull() ) {
-      image = pixmapAsDataUrl( pic.data() );
+      image = pixmapAsDataUrl( QPixmap::fromImage( pic.data() ) );
     } else if ( !pic.url().isEmpty() ) {
       image = (pic.url().startsWith( "http://" ) || pic.url().startsWith( "https://" ) ? pic.url() : "http://" + pic.url());
     } else {
-      image = "file:" + KGlobal::iconLoader()->iconPath( "personal", KIcon::Desktop );
+      image = "file:" + KIconLoader::global()->iconPath( "x-office-contact", KIconLoader::Desktop );
     }
   }
 
@@ -215,14 +206,14 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
     if ( date.isValid() )
       dynamicPart += rowFmtStr
         .arg( KABC::Addressee::birthdayLabel() )
-        .arg( KGlobal::locale()->formatDate( date, true ) );
+        .arg( KGlobal::locale()->formatDate( date, KLocale::ShortDate ) );
   }
 
   if ( fieldMask & PhoneFields ) {
-    KABC::PhoneNumber::List phones = addr.phoneNumbers();
+    const KABC::PhoneNumber::List phones = addr.phoneNumbers();
     KABC::PhoneNumber::List::ConstIterator phoneIt;
-    for ( phoneIt = phones.begin(); phoneIt != phones.end(); ++phoneIt ) {
-      QString number = (*phoneIt).number();
+    for ( phoneIt = phones.constBegin(); phoneIt != phones.constEnd(); ++phoneIt ) {
+      QString number = Qt::escape( (*phoneIt).number() );
 
       QString url;
       if ( (*phoneIt).type() & KABC::PhoneNumber::Fax )
@@ -236,28 +227,27 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
           smsURL = QString(" (<a href=\"sms:%1\">%2</a>)" ).arg( number ).arg( i18n( "SMS") );
 
         dynamicPart += rowFmtStr
-          .arg( KABC::PhoneNumber::typeLabel( (*phoneIt).type() ).replace( " ", "&nbsp;" ) )
+          .arg( (*phoneIt).typeLabel().replace( " ", "&nbsp;" ) )
           .arg( QString::fromLatin1( "<a href=\"%1\">%2</a>%3" ).arg( url ).arg( number ).arg( smsURL ) );
       } else {
         dynamicPart += rowFmtStr
-          .arg( KABC::PhoneNumber::typeLabel( (*phoneIt).type() ).replace( " ", "&nbsp;" ) )
+          .arg( (*phoneIt).typeLabel().replace( " ", "&nbsp;" ) )
           .arg( number );
       }
     }
   }
 
   if ( fieldMask & EmailFields ) {
-    QStringList emails = addr.emails();
+    const QStringList emails = addr.emails();
     QStringList::ConstIterator emailIt;
     QString type = i18n( "Email" );
-    for ( emailIt = emails.begin(); emailIt != emails.end(); ++emailIt ) {
-      QString fullEmail = addr.fullEmail( *emailIt );
-      QUrl::encode( fullEmail );
+    for ( emailIt = emails.constBegin(); emailIt != emails.constEnd(); ++emailIt ) {
+      QByteArray fullEmail = KUrl::toPercentEncoding( addr.fullEmail( *emailIt ) );
 
       if ( linkMask & EmailLinks ) {
         dynamicPart += rowFmtStr.arg( type )
           .arg( QString::fromLatin1( "<a href=\"mailto:%1\">%2</a>" )
-          .arg( fullEmail, *emailIt ) );
+          .arg( fullEmail, Qt::escape( *emailIt ) ) );
       } else {
         dynamicPart += rowFmtStr.arg( type ).arg( *emailIt );
       }
@@ -268,11 +258,11 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
     if ( !addr.url().url().isEmpty() ) {
       QString url;
       if ( linkMask & URLLinks ) {
-        url = (addr.url().url().startsWith( "http://" ) || addr.url().url().startsWith( "https://" ) ? addr.url().prettyURL() :
-          "http://" + addr.url().prettyURL());
-        url = KStringHandler::tagURLs( url );
+        url = (addr.url().url().startsWith( "http://" ) || addr.url().url().startsWith( "https://" ) ? addr.url().url() :
+          "http://" + addr.url().url());
+        url = KStringHandler::tagUrls( url );
       } else {
-        url = addr.url().prettyURL();
+        url = addr.url().url();
       }
       dynamicPart += rowFmtStr.arg( i18n("Homepage") ).arg( url );
     }
@@ -280,40 +270,20 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
     QString blog = addr.custom( "KADDRESSBOOK", "BlogFeed" );
     if ( !blog.isEmpty() ) {
       if ( linkMask & URLLinks ) {
-        blog = KStringHandler::tagURLs( blog );
+        blog = KStringHandler::tagUrls( blog );
       }
       dynamicPart += rowFmtStr.arg( i18n("Blog Feed") ).arg( blog );
     }
   }
 
   if ( fieldMask & AddressFields ) {
-    KABC::Address::List addresses = addr.addresses();
+    const KABC::Address::List addresses = addr.addresses();
     KABC::Address::List::ConstIterator addrIt;
-    for ( addrIt = addresses.begin(); addrIt != addresses.end(); ++addrIt ) {
+    for ( addrIt = addresses.constBegin(); addrIt != addresses.constEnd(); ++addrIt ) {
       if ( (*addrIt).label().isEmpty() ) {
         QString formattedAddress;
 
-#if KDE_IS_VERSION(3,1,90)
-        formattedAddress = (*addrIt).formattedAddress().stripWhiteSpace();
-#else
-        if ( !(*addrIt).street().isEmpty() )
-          formattedAddress += (*addrIt).street() + "\n";
-
-        if ( !(*addrIt).postOfficeBox().isEmpty() )
-          formattedAddress += (*addrIt).postOfficeBox() + "\n";
-
-        formattedAddress += (*addrIt).locality() + QString::fromLatin1(" ") + (*addrIt).region();
-
-        if ( !(*addrIt).postalCode().isEmpty() )
-          formattedAddress += QString::fromLatin1(", ") + (*addrIt).postalCode();
-
-        formattedAddress += "\n";
-
-        if ( !(*addrIt).country().isEmpty() )
-          formattedAddress += (*addrIt).country() + "\n";
-
-        formattedAddress += (*addrIt).extended();
-#endif
+        formattedAddress = Qt::escape( (*addrIt).formattedAddress().trimmed() );
 
         formattedAddress = formattedAddress.replace( '\n', "<br>" );
 
@@ -351,7 +321,8 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
     // @STYLE@ - substitute the cell style in first, and append
     // the data afterwards (keeps us safe from possible % signs
     // in either one).
-    notes = rowFmtStr.arg( i18n( "Notes" ) ).arg( addr.note().replace( '\n', "<br>" ) ) ;
+    notes = Qt::escape( addr.note() );
+    notes = rowFmtStr.arg( i18n( "Notes" ) ).arg( notes.replace( '\n', "<br>" ) ) ;
   }
 
   QString customData;
@@ -362,8 +333,9 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
       titleMap.insert( "Profession", i18n( "Profession" ) );
       titleMap.insert( "AssistantsName", i18n( "Assistant's Name" ) );
       titleMap.insert( "ManagersName", i18n( "Manager's Name" ) );
-      titleMap.insert( "SpousesName", i18n( "Partner's Name" ) );
+      titleMap.insert( "SpousesName", i18nc( "Wife/Husband/...", "Partner's Name" ) );
       titleMap.insert( "Office", i18n( "Office" ) );
+      titleMap.insert( "IMAddress", i18n( "IM Address" ) );
       titleMap.insert( "Anniversary", i18n( "Anniversary" ) );
     }
 
@@ -377,44 +349,40 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
           customEntry.remove( "KADDRESSBOOK-X-" );
           customEntry.remove( "KADDRESSBOOK-" );
 
-          int pos = customEntry.find( ':' );
+          int pos = customEntry.indexOf( ':' );
           QString key = customEntry.left( pos );
           const QString value = customEntry.mid( pos + 1 );
 
-          // blog and im address is handled separated
+          // blog and im address are handled separated
           if ( key == "BlogFeed" || key == "IMAddress" )
             continue;
 
-          const QMap<QString, QString>::ConstIterator keyIt = titleMap.find( key );
-          if ( keyIt != titleMap.end() )
-            key = keyIt.data();
+          const QMap<QString, QString>::ConstIterator keyIt = titleMap.constFind( key );
+          if ( keyIt != titleMap.constEnd() )
+            key = keyIt.value();
 
-          customData += rowFmtStr.arg( key ).arg( value ) ;
+          customData += rowFmtStr.arg( key ).arg( Qt::escape( value ) ) ;
         }
       }
     }
   }
 
-  QString name( addr.realName() );
-  QString role( addr.role() );
-  QString organization( addr.organization() );
+  QString name( Qt::escape( addr.realName() ) );
+  QString role( Qt::escape( addr.role() ) );
+  QString organization( Qt::escape( addr.organization() ) );
 
   if ( fieldMask & IMFields ) {
 
     const QString imAddress = addr.custom( "KADDRESSBOOK", "X-IMAddress" );
     if ( !imAddress.isEmpty() ) {
-      customData += rowFmtStr.arg( i18n( "IM Address" ) ).arg( imAddress ) ;
+      customData += rowFmtStr.arg( i18n( "IM Address" ) ).arg( Qt::escape( imAddress ) ) ;
     }
 
+/*
     if ( proxy ) {
       if ( proxy->isPresent( addr.uid() ) && proxy->presenceNumeric( addr.uid() ) > 0 ) {
         // set image source to either a QMimeSourceFactory key or a data:/ URL
-        QString imgSrc;
-        if ( internalLoading ) {
-          imgSrc = QString::fromLatin1( "im_status_%1_image").arg( addr.uid() );
-          QMimeSourceFactory::defaultFactory()->setPixmap( imgSrc, proxy->presenceIcon( addr.uid() ) );
-        } else
-          imgSrc = pixmapAsDataUrl( proxy->presenceIcon( addr.uid() ) );
+        QString imgSrc = pixmapAsDataUrl( proxy->presenceIcon( addr.uid() ) );
 
         // make the status a link, if required
         QString imStatus;
@@ -432,6 +400,7 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
                     );
       }
     }
+*/
   }
 
   // @STYLE@ - construct the string by parts, substituting in
@@ -448,7 +417,7 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
     "<td align=\"right\" valign=\"top\" width=\"30%\" rowspan=\"3\" %2>")
     .arg( cellStyle ) );
   strAddr.append( QString::fromLatin1(
-    "<img src=\"%1\" width=\"50\" vspace=\"1\">" // image
+    "<img src=\"%1\" width=\"75\" vspace=\"1\">" // image
     "</td>")
     .arg( image ) );
   strAddr.append( QString::fromLatin1(
@@ -485,24 +454,35 @@ QString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pro
   strAddr.append( customData );
   strAddr.append( QString::fromLatin1( "</table></div>\n" ) );
 
+  if ( addr.resource() ) {
+    QString addrBookName = addr.resource()->resourceName();
+    KABC::ResourceABC *r = dynamic_cast<KABC::ResourceABC*>( addr.resource() );
+    if ( r && !r->subresources().isEmpty() ) {
+      const QString subRes = r->uidToResourceMap()[ addr.uid() ];
+      const QString label = r->subresourceLabel( subRes );
+      if ( !label.isEmpty() )
+        addrBookName = label;
+    }
+    strAddr.append( i18n( "<p><b>Address book</b>: %1</p>", addrBookName ) );
+  }
   return strAddr;
 }
 
 QString AddresseeView::pixmapAsDataUrl( const QPixmap& pixmap )
 {
   QByteArray ba;
-  QBuffer buffer( ba );
-  buffer.open( IO_WriteOnly );
+  QBuffer buffer( &ba, 0 );
+  buffer.open( QIODevice::WriteOnly );
   pixmap.save( &buffer, "PNG" );
   QString encoded( "data:image/png;base64," );
-  encoded.append( KCodecs::base64Encode( ba ) );
+  encoded.append( ba.toBase64() );
   return encoded;
 }
 
 void AddresseeView::updateView()
 {
   // clear view
-  setText( QString::null );
+  setPlainText( QString() );
 
   if ( mAddressee.isEmpty() )
     return;
@@ -539,34 +519,33 @@ void AddresseeView::updateView()
     "%3" // dynamic part
     "</body>"
     "</html>" )
-     .arg( KGlobalSettings::textColor().name() )
-     .arg( KGlobalSettings::baseColor().name() )
+     .arg( KColorScheme( QPalette::Active, KColorScheme::View ).foreground().color().name() )
+     .arg( KColorScheme( QPalette::Active, KColorScheme::View ).background().color().name() )
      .arg( strAddr );
 
   QString imageURL = QString( "contact_%1_image" ).arg( mAddressee.uid() );
 
   KABC::Picture picture = mAddressee.photo();
   if ( picture.isIntern() && !picture.data().isNull() )
-    QMimeSourceFactory::defaultFactory()->setImage( imageURL, picture.data() );
+    document()->addResource( QTextDocument::ImageResource, imageURL, picture.data() );
   else {
     if ( !picture.url().isEmpty() ) {
       if ( mImageData.count() > 0 )
-        QMimeSourceFactory::defaultFactory()->setImage( imageURL, mImageData );
+        document()->addResource( QTextDocument::ImageResource, imageURL, QImage::fromData( mImageData ) );
       else {
-        mImageJob = KIO::get( KURL( picture.url() ), false, false );
+        mImageJob = KIO::get( KUrl( picture.url() ), KIO::NoReload, KIO::HideProgressInfo );
         connect( mImageJob, SIGNAL( data( KIO::Job*, const QByteArray& ) ),
                  this, SLOT( data( KIO::Job*, const QByteArray& ) ) );
-        connect( mImageJob, SIGNAL( result( KIO::Job* ) ),
-                 this, SLOT( result( KIO::Job* ) ) );
+        connect( mImageJob, SIGNAL( result( KJob* ) ),
+                 this, SLOT( result( KJob* ) ) );
       }
     } else {
-      QMimeSourceFactory::defaultFactory()->setPixmap( imageURL,
-        KGlobal::iconLoader()->loadIcon( "personal", KIcon::Desktop, 128 ) );
+      document()->addResource( QTextDocument::ImageResource, imageURL, KIcon( "x-office-contact" ).pixmap( 128, 128 ) );
     }
   }
 
   // at last display it...
-  setText( strAddr );
+  setHtml( strAddr );
 }
 
 KABC::Addressee AddresseeView::addressee() const
@@ -576,21 +555,21 @@ KABC::Addressee AddresseeView::addressee() const
 
 void AddresseeView::urlClicked( const QString &url )
 {
-  kapp->invokeBrowser( url );
+  KToolInvocation::invokeBrowser( url );
 }
 
 void AddresseeView::emailClicked( const QString &email )
 {
   if ( email.startsWith( "mailto:" ) )
-    kapp->invokeMailer( email.mid( 7 ), QString::null );
+    KToolInvocation::invokeMailer( email.mid( 7 ), QString() );
   else
-    kapp->invokeMailer( email, QString::null );
+    KToolInvocation::invokeMailer( email, QString() );
 }
 
 void AddresseeView::phoneNumberClicked( const QString &number )
 {
-  KConfig config( "kaddressbookrc" );
-  config.setGroup( "General" );
+  KConfig _config( "kaddressbookrc" );
+  KConfigGroup config(&_config, "General" );
   QString commandLine = config.readEntry( "PhoneHookApplication" );
 
   if ( commandLine.isEmpty() ) {
@@ -599,13 +578,13 @@ void AddresseeView::phoneNumberClicked( const QString &number )
   }
 
   commandLine.replace( "%N", number );
-  KRun::runCommand( commandLine );
+  KRun::runCommand( commandLine, topLevelWidget());
 }
 
 void AddresseeView::smsTextClicked( const QString &number )
 {
-  KConfig config( "kaddressbookrc" );
-  config.setGroup( "General" );
+  KConfig _config( "kaddressbookrc" );
+  KConfigGroup config(&_config, "General" );
   QString commandLine = config.readEntry( "SMSHookApplication" );
 
   if ( commandLine.isEmpty() ) {
@@ -621,25 +600,27 @@ void AddresseeView::smsTextClicked( const QString &number )
 
 void AddresseeView::sendSMS( const QString &number, const QString &text )
 {
-  KConfig config( "kaddressbookrc" );
-  config.setGroup( "General" );
+  KConfig _config( "kaddressbookrc" );
+  KConfigGroup config(&_config, "General" );
   QString commandLine = config.readEntry( "SMSHookApplication" );
 
-  KTempFile file ;
-  QTextStream* stream = file.textStream();
-  *stream << text;
-  file.close();
+  KTemporaryFile file;
+  file.setAutoRemove(false);
+  file.open();
+  QTextStream stream ( &file );
+  stream << text;
+  stream.flush();
 
   commandLine.replace( "%N", number );
-  commandLine.replace( "%F", file.name() );
+  commandLine.replace( "%F", file.fileName() );
 
-  KRun::runCommand( commandLine );
+  KRun::runCommand( commandLine, topLevelWidget());
 }
 
 void AddresseeView::faxNumberClicked( const QString &number )
 {
-  KConfig config( "kaddressbookrc" );
-  config.setGroup( "General" );
+  KConfig _config( "kaddressbookrc" );
+  KConfigGroup config(&_config, "General" );
   QString commandLine = config.readEntry( "FaxHookApplication", "kdeprintfax --phone %N" );
 
   if ( commandLine.isEmpty() ) {
@@ -648,26 +629,26 @@ void AddresseeView::faxNumberClicked( const QString &number )
   }
 
   commandLine.replace( "%N", number );
-  KRun::runCommand( commandLine );
+  KRun::runCommand( commandLine, topLevelWidget());
 }
 
 void AddresseeView::imAddressClicked()
 {
-  mKIMProxy->chatWithContact( mAddressee.uid() );
+  // mKIMProxy->chatWithContact( mAddressee.uid() );
 }
 
-QPopupMenu *AddresseeView::createPopupMenu( const QPoint& )
+void AddresseeView::contextMenuEvent(QContextMenuEvent *e)
 {
-  QPopupMenu *menu = new QPopupMenu( this );
-  mActionShowBirthday->plug( menu );
-  mActionShowAddresses->plug( menu );
-  mActionShowEmails->plug( menu );
-  mActionShowPhones->plug( menu );
-  mActionShowURLs->plug( menu );
-  mActionShowIMAddresses->plug( menu );
-  mActionShowCustomFields->plug( menu );
-
-  return menu;
+  QMenu *menu = new QMenu( this );
+  menu->addAction( mActionShowBirthday );
+  menu->addAction( mActionShowAddresses );
+  menu->addAction( mActionShowEmails );
+  menu->addAction( mActionShowPhones );
+  menu->addAction( mActionShowURLs );
+  menu->addAction( mActionShowIMAddresses );
+  menu->addAction( mActionShowCustomFields );
+  menu->exec(e->globalPos());
+  delete menu;
 }
 
 void AddresseeView::slotMailClicked( const QString&, const QString &email )
@@ -678,13 +659,13 @@ void AddresseeView::slotMailClicked( const QString&, const QString &email )
 void AddresseeView::slotUrlClicked( const QString &url )
 {
   if ( url.startsWith( "phone:" ) )
-    phoneNumberClicked( strippedNumber( url.mid( 8 ) ) );
+    phoneNumberClicked( strippedNumber( url.mid( 6 ) ) );
   else if ( url.startsWith( "sms:" ) )
-    smsTextClicked( strippedNumber( url.mid( 6 ) ) );
+    smsTextClicked( strippedNumber( url.mid( 4 ) ) );
   else if ( url.startsWith( "fax:" ) )
-    faxNumberClicked( strippedNumber( url.mid( 6 ) ) );
+    faxNumberClicked( strippedNumber( url.mid( 4 ) ) );
   else if ( url.startsWith( "addr:" ) )
-    emit addressClicked( url.mid( 7 ) );
+    emit addressClicked( url.mid( 5 ) );
   else if ( url.startsWith( "im:" ) )
     imAddressClicked();
   else
@@ -697,34 +678,34 @@ void AddresseeView::slotHighlighted( const QString &link )
     QString email = link.mid( 7 );
 
     emit emailHighlighted( email );
-    emit highlightedMessage( i18n( "Send mail to '%1'" ).arg( email ) );
+    emit highlightedMessage( i18n( "Send mail to '%1'", email ) );
   } else if ( link.startsWith( "phone:" ) ) {
-    QString number = link.mid( 8 );
-
-    emit phoneNumberHighlighted( strippedNumber( number ) );
-    emit highlightedMessage( i18n( "Call number %1" ).arg( number ) );
-  } else if ( link.startsWith( "fax:" ) ) {
     QString number = link.mid( 6 );
 
+    emit phoneNumberHighlighted( strippedNumber( number ) );
+    emit highlightedMessage( i18n( "Call number %1", number ) );
+  } else if ( link.startsWith( "fax:" ) ) {
+    QString number = link.mid( 4 );
+
     emit faxNumberHighlighted( strippedNumber( number ) );
-    emit highlightedMessage( i18n( "Send fax to %1" ).arg( number ) );
+    emit highlightedMessage( i18n( "Send fax to %1", number ) );
   } else if ( link.startsWith( "addr:" ) ) {
     emit highlightedMessage( i18n( "Show address on map" ) );
   } else if ( link.startsWith( "sms:" ) ) {
-    QString number = link.mid( 6 );
-    emit highlightedMessage( i18n( "Send SMS to %1" ).arg( number ) );
+    QString number = link.mid( 4 );
+    emit highlightedMessage( i18n( "Send SMS to %1", number ) );
   } else if ( link.startsWith( "http:" ) || link.startsWith( "https:" ) ) {
     emit urlHighlighted( link );
-    emit highlightedMessage( i18n( "Open URL %1" ).arg( link ) );
+    emit highlightedMessage( i18n( "Open URL %1", link ) );
   } else if ( link.startsWith( "im:" ) ) {
-    emit highlightedMessage( i18n( "Chat with %1" ).arg( mAddressee.realName() ) );
+    emit highlightedMessage( i18n( "Chat with %1", mAddressee.realName() ) );
   } else
     emit highlightedMessage( "" );
 }
 
 void AddresseeView::slotPresenceChanged( const QString &uid )
 {
-  kdDebug() << k_funcinfo << " uid is: " << uid << " mAddressee is: " << mAddressee.uid() << endl;
+  kDebug() <<" uid is:" << uid <<" mAddressee is:" << mAddressee.uid();
   if ( uid == mAddressee.uid() )
     updateView();
 }
@@ -748,7 +729,7 @@ void AddresseeView::data( KIO::Job*, const QByteArray &d )
   memcpy( mImageData.data() + oldSize, d.data(), d.size() );
 }
 
-void AddresseeView::result( KIO::Job *job )
+void AddresseeView::result( KJob *job )
 {
   mImageJob = 0;
 
@@ -760,26 +741,26 @@ void AddresseeView::result( KIO::Job *job )
 
 void AddresseeView::load()
 {
-  mConfig->setGroup( "AddresseeViewSettings" );
-  mActionShowBirthday->setChecked( mConfig->readBoolEntry( "ShowBirthday", false ) );
-  mActionShowAddresses->setChecked( mConfig->readBoolEntry( "ShowAddresses", true ) );
-  mActionShowEmails->setChecked( mConfig->readBoolEntry( "ShowEmails", true ) );
-  mActionShowPhones->setChecked( mConfig->readBoolEntry( "ShowPhones", true ) );
-  mActionShowURLs->setChecked( mConfig->readBoolEntry( "ShowURLs", true ) );
-  mActionShowIMAddresses->setChecked( mConfig->readBoolEntry( "ShowIMAddresses", false ) );
-  mActionShowCustomFields->setChecked( mConfig->readBoolEntry( "ShowCustomFields", false ) );
+  KConfigGroup group( mConfig, "AddresseeViewSettings" );
+  mActionShowBirthday->setChecked( group.readEntry( "ShowBirthday", false ) );
+  mActionShowAddresses->setChecked( group.readEntry( "ShowAddresses", true ) );
+  mActionShowEmails->setChecked( group.readEntry( "ShowEmails", true ) );
+  mActionShowPhones->setChecked( group.readEntry( "ShowPhones", true ) );
+  mActionShowURLs->setChecked( group.readEntry( "ShowURLs", true ) );
+  mActionShowIMAddresses->setChecked( group.readEntry( "ShowIMAddresses", false ) );
+  mActionShowCustomFields->setChecked( group.readEntry( "ShowCustomFields", false ) );
 }
 
 void AddresseeView::save()
 {
-  mConfig->setGroup( "AddresseeViewSettings" );
-  mConfig->writeEntry( "ShowBirthday", mActionShowBirthday->isChecked() );
-  mConfig->writeEntry( "ShowAddresses", mActionShowAddresses->isChecked() );
-  mConfig->writeEntry( "ShowEmails", mActionShowEmails->isChecked() );
-  mConfig->writeEntry( "ShowPhones", mActionShowPhones->isChecked() );
-  mConfig->writeEntry( "ShowURLs", mActionShowURLs->isChecked() );
-  mConfig->writeEntry( "ShowIMAddresses", mActionShowIMAddresses->isChecked() );
-  mConfig->writeEntry( "ShowCustomFields", mActionShowCustomFields->isChecked() );
+  KConfigGroup group( mConfig, "AddresseeViewSettings" );
+  group.writeEntry( "ShowBirthday", mActionShowBirthday->isChecked() );
+  group.writeEntry( "ShowAddresses", mActionShowAddresses->isChecked() );
+  group.writeEntry( "ShowEmails", mActionShowEmails->isChecked() );
+  group.writeEntry( "ShowPhones", mActionShowPhones->isChecked() );
+  group.writeEntry( "ShowURLs", mActionShowURLs->isChecked() );
+  group.writeEntry( "ShowIMAddresses", mActionShowIMAddresses->isChecked() );
+  group.writeEntry( "ShowCustomFields", mActionShowCustomFields->isChecked() );
   mConfig->sync();
 }
 
@@ -787,9 +768,9 @@ QString AddresseeView::strippedNumber( const QString &number )
 {
   QString retval;
 
-  for ( uint i = 0; i < number.length(); ++i ) {
+  for ( int i = 0; i < number.length(); ++i ) {
     QChar c = number[ i ];
-    if ( c.isDigit() || c == '*' || c == '#' || c == '+' && i == 0 )
+    if ( c.isDigit() || c == '*' || c == '#' || (c == '+' && i == 0) )
       retval.append( c );
   }
 
